<?php
// Start session
session_start();

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true || $_SESSION["role"] !== "admin") {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Define variables
$error_message = "";
$success_message = "";
$user = [];

// Check if user ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    echo "<script>window.location.href = 'user-manager.php';</script>";
    exit;
}

$user_id = (int)$_GET['id'];

// Process form submission
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["update_user"])) {
    $fullname = trim($_POST["fullname"]);
    $email = trim($_POST["email"]);
    $role = trim($_POST["role"]);
    
    // Basic validation
    if (empty($fullname) || empty($role)) {
        $error_message = "Full name and role are required fields";
    } else {
        try {
            // Update user details
            $sql = "UPDATE users SET fullname = ?, email = ?, role = ? WHERE id = ?";
            $stmt = $pdo->prepare($sql);
            $stmt->execute([$fullname, $email, $role, $user_id]);
            
            $success_message = "User details updated successfully";
            
            // Refresh user data after update
            $sql = "SELECT username, fullname, email, role FROM users WHERE id = ?";
            $stmt = $pdo->prepare($sql);
            $stmt->execute([$user_id]);
            $user = $stmt->fetch(PDO::FETCH_ASSOC);
            
        } catch (PDOException $e) {
            $error_message = "Database error: " . $e->getMessage();
        }
    }
} else {
    // Get user details
    try {
        $sql = "SELECT username, fullname, email, role FROM users WHERE id = ?";
        $stmt = $pdo->prepare($sql);
        $stmt->execute([$user_id]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$user) {
            echo "<script>alert('User not found'); window.location.href = 'user-manager.php';</script>";
            exit;
        }
    } catch (PDOException $e) {
        $error_message = "Database error: " . $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit User - Emergency Code System</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <!-- Add favicon link -->
    <link rel="icon" href="favicon.ico" type="image/x-icon">
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">Edit User Details</h1>
            <div class="flex items-center space-x-4">
                <a href="user-manager.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">
                    <i class="fas fa-arrow-left mr-1"></i> Back to User Manager
                </a>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($_SESSION["fullname"]); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto max-w-3xl">
            <?php if(!empty($error_message)): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
                    <p><?php echo $error_message; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if(!empty($success_message)): ?>
                <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-4" role="alert">
                    <p><?php echo $success_message; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="bg-white rounded-lg shadow-md p-6">
                <div class="flex items-center mb-6">
                    <div class="bg-blue-100 p-3 rounded-full mr-4">
                        <i class="fas fa-user text-blue-500 text-xl"></i>
                    </div>
                    <div>
                        <h2 class="text-xl font-bold"><?php echo htmlspecialchars($user['username']); ?></h2>
                        <p class="text-gray-600">Editing user details</p>
                    </div>
                </div>
                
                <form method="post" action="">
                    <div class="mb-4">
                        <label for="username" class="block text-sm font-medium text-gray-700 mb-1">Username</label>
                        <input type="text" id="username" value="<?php echo htmlspecialchars($user['username']); ?>" 
                               class="w-full px-3 py-2 border border-gray-300 rounded-md bg-gray-100" readonly disabled>
                        <p class="text-xs text-gray-500 mt-1">Username cannot be changed</p>
                    </div>
                    
                    <div class="mb-4">
                        <label for="fullname" class="block text-sm font-medium text-gray-700 mb-1">Full Name *</label>
                        <input type="text" name="fullname" id="fullname" value="<?php echo htmlspecialchars($user['fullname']); ?>" required
                               class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500">
                    </div>
                    
                    <div class="mb-4">
                        <label for="email" class="block text-sm font-medium text-gray-700 mb-1">Email</label>
                        <input type="email" name="email" id="email" value="<?php echo htmlspecialchars($user['email'] ?? ''); ?>"
                               class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500">
                    </div>
                    
                    <div class="mb-6">
                        <label for="role" class="block text-sm font-medium text-gray-700 mb-1">Role *</label>
                        <select name="role" id="role" required 
                                class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500">
                            <option value="reporter" <?php echo ($user['role'] === 'reporter') ? 'selected' : ''; ?>>Reporter</option>
                            <option value="admin" <?php echo ($user['role'] === 'admin') ? 'selected' : ''; ?>>Admin</option>
                        </select>
                    </div>
                    
                    <div class="flex justify-between items-center border-t border-gray-200 pt-4">
                        <a href="user-manager.php" class="text-gray-600 hover:text-gray-800">
                            <i class="fas fa-arrow-left mr-1"></i> Cancel
                        </a>
                        <button type="submit" name="update_user" class="bg-blue-500 hover:bg-blue-600 text-white px-4 py-2 rounded">
                            <i class="fas fa-save mr-1"></i> Save Changes
                        </button>
                    </div>
                </form>
                
                <div class="mt-8 pt-6 border-t border-gray-200">
                    <h3 class="font-bold text-lg mb-4">Additional Actions</h3>
                    
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <a href="#" onclick="showResetPassword(<?php echo $user_id; ?>, '<?php echo htmlspecialchars($user['username']); ?>')" 
                           class="bg-yellow-100 hover:bg-yellow-200 text-yellow-800 p-4 rounded flex items-center">
                            <i class="fas fa-key text-yellow-600 mr-3 text-xl"></i>
                            <div>
                                <h4 class="font-semibold">Reset Password</h4>
                                <p class="text-sm">Change user's password</p>
                            </div>
                        </a>
                        
                        <a href="update-duty-status.php?user_id=<?php echo $user_id; ?>" 
                           class="bg-green-100 hover:bg-green-200 text-green-800 p-4 rounded flex items-center">
                            <i class="fas fa-calendar-check text-green-600 mr-3 text-xl"></i>
                            <div>
                                <h4 class="font-semibold">Update Duty Status</h4>
                                <p class="text-sm">Manage user's duty assignment</p>
                            </div>
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </main>
    
    <!-- Password Reset Modal -->
    <div id="resetPasswordModal" class="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center hidden">
        <div class="bg-white rounded-lg max-w-md w-full p-6">
            <h3 class="text-lg font-bold mb-4">Reset Password</h3>
            <form method="post" action="user-manager.php">
                <input type="hidden" name="action" value="reset">
                <input type="hidden" name="user_id" id="reset_user_id" value="<?php echo $user_id; ?>">
                
                <p class="mb-4">Reset password for: <span id="reset_username" class="font-bold"><?php echo htmlspecialchars($user['username']); ?></span></p>
                
                <div class="mb-4">
                    <label for="new_password" class="block text-sm font-medium text-gray-700 mb-1">New Password</label>
                    <input type="password" name="new_password" id="new_password" required 
                           class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" onclick="hideResetPassword()" 
                            class="bg-gray-300 hover:bg-gray-400 text-gray-800 font-bold py-2 px-4 rounded">
                        Cancel
                    </button>
                    <button type="submit" 
                            class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded">
                        Reset Password
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
    </footer>
    
    <script>
        function showResetPassword(userId, username) {
            document.getElementById('reset_user_id').value = userId;
            document.getElementById('reset_username').textContent = username;
            document.getElementById('resetPasswordModal').classList.remove('hidden');
        }
        
        function hideResetPassword() {
            document.getElementById('resetPasswordModal').classList.add('hidden');
        }
    </script>
</body>
</html>