// Client-side Text-to-Speech functionality for browsers that support it
document.addEventListener('DOMContentLoaded', function() {
    // Check if browser supports speech synthesis
    if (!window.speechSynthesis) {
        console.warn("This browser does not support speech synthesis.");
        return;
    }
    
    // Function to speak text
    window.speakAnnouncement = function(text, repeat = 1) {
        // Cancel any ongoing speech
        window.speechSynthesis.cancel();
        
        // Function to create an utterance with the best available voice
        const createUtterance = () => {
            const utterance = new SpeechSynthesisUtterance(text);
            
            // Get available voices
            const voices = window.speechSynthesis.getVoices();
            
            // Priority for voice selection:
            // 1. English male voice (more authoritative for announcements)
            // 2. Any English voice
            // 3. Any available voice
            
            const englishMaleVoice = voices.find(voice => 
                voice.lang.startsWith('en') && 
                (voice.name.includes('Male') || voice.name.includes('David') || voice.name.includes('Daniel'))
            );
            
            const anyEnglishVoice = voices.find(voice => voice.lang.startsWith('en'));
            
            // Set voice based on availability
            if (englishMaleVoice) {
                utterance.voice = englishMaleVoice;
            } else if (anyEnglishVoice) {
                utterance.voice = anyEnglishVoice;
            }
            
            // Optimize speech parameters for emergency announcements
            utterance.rate = 0.9;     // Slightly slower for clarity
            utterance.pitch = 1.0;    // Natural pitch
            utterance.volume = 1.0;   // Maximum volume
            
            return utterance;
        };
        
        // Function to speak with repetition
        const speakWithRepetition = (remainingRepeats) => {
            if (remainingRepeats <= 0) return;
            
            const utterance = createUtterance();
            
            // When speech ends, speak again if there are remaining repetitions
            utterance.onend = () => {
                // Add a short pause between repetitions
                setTimeout(() => {
                    speakWithRepetition(remainingRepeats - 1);
                }, 1000);
            };
            
            // Start speaking
            window.speechSynthesis.speak(utterance);
        };
        
        // Start the first utterance
        speakWithRepetition(repeat);
    };
    
    // Ensure voices are loaded (needed for Chrome)
    if (window.speechSynthesis.onvoiceschanged !== undefined) {
        window.speechSynthesis.onvoiceschanged = function() {
            console.log("Voices loaded: " + window.speechSynthesis.getVoices().length);
        };
    }
});
