<?php
// This API returns a list of all buildings for the dropdown filter

// Enable error reporting for troubleshooting but suppress display
error_reporting(E_ALL);
ini_set('display_errors', 0);

// Start session
session_start();

// Check if user is logged in
// Uncomment this in production
// if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
//     header('Content-Type: application/json');
//     echo json_encode(['success' => false, 'error' => 'Unauthorized']);
//     exit;
// }

// Include database connection
require_once 'db-connection.php';

// Set response headers
header('Content-Type: application/json');

try {
    // Query all active buildings from the buildings table
    $query = "SELECT id, name, short_code FROM buildings WHERE active = 1 ORDER BY name";
    $stmt = $pdo->query($query);
    $buildings = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // Return success response
    echo json_encode([
        'success' => true,
        'buildings' => $buildings
    ]);
    
} catch (Exception $e) {
    // Log the error
    error_log('Database Error: ' . $e->getMessage());
    
    // Return error response
    http_response_code(500);
    echo json_encode([
        'success' => false,
        'error' => 'Failed to retrieve buildings',
        'message' => $e->getMessage()
    ]);
}