<?php
// Basic PHP info script for troubleshooting

// Show only critical info for security
$safe_mode = ini_get('safe_mode') ? 'On' : 'Off';
$display_errors = ini_get('display_errors') ? 'On' : 'Off';
$max_execution_time = ini_get('max_execution_time');
$memory_limit = ini_get('memory_limit');
$post_max_size = ini_get('post_max_size');
$upload_max_filesize = ini_get('upload_max_filesize');
$php_version = phpversion();

// Check session functionality
session_start();
$_SESSION['test'] = 'Session working';
$session_working = isset($_SESSION['test']) && $_SESSION['test'] === 'Session working';

// Check if important extensions are loaded
$pdo_mysql = extension_loaded('pdo_mysql') ? 'Loaded' : 'Not loaded';
$json = extension_loaded('json') ? 'Loaded' : 'Not loaded';

// Output limited info
echo "<h1>PHP Environment Information</h1>";
echo "<p>This page shows limited PHP information for troubleshooting purposes.</p>";

echo "<h2>PHP Version</h2>";
echo "<p>$php_version</p>";

echo "<h2>Critical Settings</h2>";
echo "<ul>";
echo "<li>Safe Mode: $safe_mode</li>";
echo "<li>Display Errors: $display_errors</li>";
echo "<li>Max Execution Time: $max_execution_time seconds</li>";
echo "<li>Memory Limit: $memory_limit</li>";
echo "<li>POST Max Size: $post_max_size</li>";
echo "<li>Upload Max Filesize: $upload_max_filesize</li>";
echo "</ul>";

echo "<h2>Session Test</h2>";
echo $session_working ? "<p style='color: green;'>Sessions are working correctly</p>" : "<p style='color: red;'>Session test failed</p>";

echo "<h2>Required Extensions</h2>";
echo "<ul>";
echo "<li>PDO MySQL: $pdo_mysql</li>";
echo "<li>JSON: $json</li>";
echo "</ul>";

// Test database connection if PDO is available
if (extension_loaded('pdo_mysql')) {
    echo "<h2>Database Connection Test</h2>";
    try {
        // Attempt a basic database connection with placeholder credentials
        // Replace these with your actual credentials to test
        $host = 'localhost';
        $dbname = 'bangsaho_emergency_code_system';  // Change to your database name
        $username = '[PLACEHOLDER - NOT SHOWN]';
        $password = '[PLACEHOLDER - NOT SHOWN]';
        
        echo "<p>Attempting to connect to database '{$dbname}' on '{$host}'...</p>";
        echo "<p style='color: orange;'>Note: Actual credentials not shown/used in this test.</p>";
        echo "<p>If you need to test actual connection, edit this file to use real credentials temporarily.</p>";
        
        // Don't actually create a connection without real credentials
        // $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
        // echo "<p style='color: green;'>Database connection successful!</p>";
    } catch (Exception $e) {
        echo "<p style='color: red;'>Connection would likely fail: " . $e->getMessage() . "</p>";
    }
}

echo "<h2>Server Software</h2>";
echo "<p>" . ($_SERVER['SERVER_SOFTWARE'] ?? 'Unknown') . "</p>";

echo "<h2>Document Root</h2>";
echo "<p>" . ($_SERVER['DOCUMENT_ROOT'] ?? 'Unknown') . "</p>";

echo "<h2>Script Filename</h2>";
echo "<p>" . ($_SERVER['SCRIPT_FILENAME'] ?? 'Unknown') . "</p>";
