// service-worker.js for Hospital Emergency Code Reporter

// Service worker installation
self.addEventListener('install', function(event) {
  console.log('Service Worker installing.');
  self.skipWaiting(); // Force activation
});

// Service worker activation
self.addEventListener('activate', function(event) {
  console.log('Service Worker activating.');
  return self.clients.claim(); // Take control immediately
});

// Push event listener
self.addEventListener('push', function(event) {
  console.log('Push message received.');
  
  if (event.data) {
    const data = event.data.json();
    
    // Create notification options
    const options = {
      body: data.body || 'New emergency code reported',
      icon: '/img/notification-icon.png', // Path to your notification icon
      badge: '/img/badge-icon.png', // Small icon for notification tray
      vibrate: [100, 50, 100, 50, 100], // Vibration pattern for mobile devices
      tag: 'emergency-code-notification', // Group similar notifications
      data: {
        url: data.url || '/index.php', // URL to open when notification is clicked
        codeType: data.codeType,
        location: data.location
      },
      actions: [
        {
          action: 'view',
          title: 'View Details'
        },
        {
          action: 'close',
          title: 'Dismiss'
        }
      ],
      // Make the notification more prominent for critical codes
      requireInteraction: data.critical === true
    };

    event.waitUntil(
      self.registration.showNotification(data.title || 'Emergency Code Alert', options)
    );
  }
});

// Notification click event
self.addEventListener('notificationclick', function(event) {
  console.log('Notification clicked:', event.notification.tag);
  
  // Close the notification
  event.notification.close();
  
  // Handle the notification click action
  if (event.action === 'close') {
    // User clicked "Dismiss" button, do nothing more
    return;
  }
  
  // Default action or "View Details" action - open the page
  const urlToOpen = event.notification.data.url || '/index.php';
  
  // This looks to see if the current window is already open and focuses it
  event.waitUntil(
    clients.matchAll({
      type: 'window'
    }).then(function(clientList) {
      for (let i = 0; i < clientList.length; i++) {
        const client = clientList[i];
        if (client.url === urlToOpen && 'focus' in client) {
          return client.focus();
        }
      }
      
      // If no window is already open, open a new one
      if (clients.openWindow) {
        return clients.openWindow(urlToOpen);
      }
    })
  );
});

// Notification close event (for analytics)
self.addEventListener('notificationclose', function(event) {
  console.log('Notification closed without clicking it.');
  
  // You could send analytics data back to your server here
  const codeType = event.notification.data.codeType;
  const location = event.notification.data.location;
  
  // Example of logging notification dismissals
  console.log(`User dismissed notification for ${codeType} at ${location}`);
});