# Emergency Code Audio Generation Setup

This document provides instructions for setting up the audio generation functionality for the Emergency Code Reporter system.

## Overview

The system can generate audio announcements for emergency codes in three ways:

1. **Server-side Audio Generation** - Using command-line tools like `espeak` or `festival` with `ffmpeg`
2. **Text File Fallback** - Creating text files that can be read by the browser's speech synthesis API
3. **Client-side Speech Synthesis** - Using the Web Speech API directly in the browser

## Database Setup

First, add the audio_file column to your database:

```sql
-- Run this SQL in your database
ALTER TABLE code_reports 
ADD COLUMN audio_file VARCHAR(255) NULL AFTER details;
```

## Server-side Setup (Option 1 - Recommended)

For the most reliable audio generation, install the required command-line tools on your server:

### On Debian/Ubuntu Linux:

```bash
sudo apt-get update
sudo apt-get install espeak ffmpeg
```

### On CentOS/RHEL:

```bash
sudo yum install epel-release
sudo yum install espeak ffmpeg
```

### Testing the Installation

To test if the tools are properly installed, run:

```bash
espeak "This is a test" --stdout | ffmpeg -i - -ar 44100 -ac 2 -ab 192k -f mp3 test.mp3
```

This should create a test.mp3 file in your current directory.

## Directory Setup

Create a directory for storing the audio files:

```bash
mkdir -p /path/to/your/webroot/AudioCodes
chmod 755 /path/to/your/webroot/AudioCodes
```

Make sure the web server has write permissions:

```bash
chown www-data:www-data /path/to/your/webroot/AudioCodes
```

## Client-side Fallback Setup

If server-side audio generation isn't available, the system will fall back to using client-side speech synthesis. 

1. Ensure `client-tts.js` is uploaded to your web server
2. Add this script to your HTML pages:

```html
<script src="client-tts.js"></script>
```

## Using the Audio Features

### For Administrators:

1. Once a report is submitted, a "Generate Audio" button will appear in the admin view
2. Click this button to generate an audio file for the announcement
3. After generation, a "Play" button will replace the "Generate Audio" button
4. Click the "Play" button to hear the announcement

### For All Users:

When submitting a report:
1. The system will automatically attempt to generate an audio file
2. This happens in the background after the report is submitted

## Troubleshooting

### No Audio Files Being Generated

1. Check if your server has the required tools installed:
   ```bash
   which espeak
   which ffmpeg
   ```

2. Verify the AudioCodes directory has the correct permissions:
   ```bash
   ls -la /path/to/your/webroot/AudioCodes
   ```

3. Check your web server error logs for any PHP errors

### Audio Files Generated But Not Playing

1. Ensure that your web browser allows audio playback
2. Check for JavaScript console errors
3. Verify that the audio file exists on the server

## Advanced Customization

### Changing the Voice or Speech Parameters

Edit the `generate-audio.php` file to modify:
- Announcement text format
- Speed of speech
- Voice selection
- Number of repetitions

### Using Google Cloud Text-to-Speech

For higher quality speech, you can integrate with Google Cloud Text-to-Speech API:

1. Set up a Google Cloud account
2. Enable the Text-to-Speech API
3. Install the Google Cloud PHP client library
4. Update `generate-audio.php` to use the Google API
5. Set `$useGoogleTTS = true;` in the file
