<?php
// Enable error reporting for troubleshooting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start session
session_start();

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
} else if ($_SESSION["role"] !== "admin") {
    // Redirect non-admin users
    echo "<script>window.location.href = 'index.php';</script>";
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Emergency Code Reports - Admin Panel</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">Hospital Emergency Code Reports</h1>
            <div class="flex items-center space-x-4">
                <a href="user-manager.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Manage Users</a>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($_SESSION["fullname"] ?? 'Admin'); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto">
            <div class="bg-white rounded-lg shadow p-6">
                <div class="flex justify-between items-center mb-6">
                    <h2 class="text-xl font-bold text-gray-800">Emergency Reports</h2>
                    <div class="flex space-x-2">
                        <a href="index.php" class="bg-red-500 hover:bg-red-600 text-white px-4 py-2 rounded">
                            New Report
                        </a>
                    </div>
                </div>
                
                <div class="p-4 border rounded mb-4">
                    <p>This is a simplified version of the reports page to help diagnose loading issues.</p>
                    <p>If you can see this page, then your PHP and session handling are working correctly.</p>
                </div>
                
                <div class="overflow-x-auto">
                    <table class="min-w-full divide-y divide-gray-200">
                        <thead class="bg-gray-50">
                            <tr>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">ID</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Reference ID</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Code</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Status</th>
                            </tr>
                        </thead>
                        <tbody class="bg-white divide-y divide-gray-200">
                            <?php
                            // Try to display some basic report information
                            try {
                                require_once 'db-connection.php';
                                // Simple query to get a few reports
                                $stmt = $pdo->query("SELECT id, reference_id, code_id, status FROM code_reports ORDER BY id DESC LIMIT 5");
                                $reports = $stmt->fetchAll(PDO::FETCH_ASSOC);
                                
                                if (count($reports) > 0) {
                                    foreach ($reports as $report) {
                                        echo "<tr>";
                                        echo "<td class='px-6 py-4 whitespace-nowrap'>{$report['id']}</td>";
                                        echo "<td class='px-6 py-4 whitespace-nowrap'>ECR-" . str_pad($report['reference_id'], 6, '0', STR_PAD_LEFT) . "</td>";
                                        echo "<td class='px-6 py-4 whitespace-nowrap'>{$report['code_id']}</td>";
                                        echo "<td class='px-6 py-4 whitespace-nowrap'>{$report['status']}</td>";
                                        echo "</tr>";
                                    }
                                } else {
                                    echo "<tr><td colspan='4' class='px-6 py-4 text-center'>No reports found</td></tr>";
                                }
                            } catch (Exception $e) {
                                echo "<tr><td colspan='4' class='px-6 py-4 text-center text-red-500'>Error: " . htmlspecialchars($e->getMessage()) . "</td></tr>";
                            }
                            ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
</body>
</html>
