<?php
// Simple test script to debug duty status updates
// Place this in a file named test-status-update.php

// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    die("You must be logged in to run this test.");
}

// Get user information
$userId = $_SESSION["user_id"] ?? 0;
$fullname = $_SESSION["fullname"] ?? "User";

// Include database connection
require_once 'db-connection.php';

// Initialize messages
$resultMessage = '';

// Show current user info
echo "<h2>Current User Info</h2>";
echo "User ID: $userId<br>";
echo "Name: $fullname<br>";

// Get current status
try {
    $stmt = $pdo->prepare("SELECT duty_status_id, duty_shift FROM users WHERE id = ?");
    $stmt->execute([$userId]);
    $currentStatus = $stmt->fetch(PDO::FETCH_ASSOC);
    
    echo "<h3>Current Status:</h3>";
    echo "duty_status_id: " . ($currentStatus['duty_status_id'] ?? 'NULL') . "<br>";
    echo "duty_shift: " . ($currentStatus['duty_shift'] ?? 'NULL') . "<br>";
} catch (PDOException $e) {
    echo "<p style='color:red'>Error getting current status: " . $e->getMessage() . "</p>";
}

// Test status update
if (isset($_POST['test_update'])) {
    $newStatusId = (int)$_POST['test_status_id'];
    $shift = $_POST['test_shift'] ?? null;
    
    echo "<h3>Testing Update:</h3>";
    echo "New Status ID: $newStatusId<br>";
    echo "New Shift: $shift<br>";
    
    try {
        // Direct update query
        $sql = "UPDATE users SET duty_status_id = ?, duty_shift = ? WHERE id = ?";
        $stmt = $pdo->prepare($sql);
        $result = $stmt->execute([$newStatusId, $shift, $userId]);
        
        if ($result) {
            echo "<p style='color:green'>Update succeeded! Affected rows: " . $stmt->rowCount() . "</p>";
            
            // Re-check status
            $stmt = $pdo->prepare("SELECT duty_status_id, duty_shift FROM users WHERE id = ?");
            $stmt->execute([$userId]);
            $newStatus = $stmt->fetch(PDO::FETCH_ASSOC);
            
            echo "<h3>New Status:</h3>";
            echo "duty_status_id: " . ($newStatus['duty_status_id'] ?? 'NULL') . "<br>";
            echo "duty_shift: " . ($newStatus['duty_shift'] ?? 'NULL') . "<br>";
        } else {
            echo "<p style='color:red'>Update failed!</p>";
        }
    } catch (PDOException $e) {
        echo "<p style='color:red'>Error updating status: " . $e->getMessage() . "</p>";
    }
}

// List available duty statuses
try {
    $stmt = $pdo->query("SELECT id, status_name, description FROM duty_status ORDER BY id");
    $statuses = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<h3>Available Duty Statuses:</h3>";
    echo "<table border='1' cellpadding='5'>";
    echo "<tr><th>ID</th><th>Name</th><th>Description</th></tr>";
    
    foreach ($statuses as $status) {
        echo "<tr>";
        echo "<td>" . $status['id'] . "</td>";
        echo "<td>" . $status['status_name'] . "</td>";
        echo "<td>" . ($status['description'] ?? '') . "</td>";
        echo "</tr>";
    }
    
    echo "</table>";
} catch (PDOException $e) {
    echo "<p style='color:red'>Error getting duty statuses: " . $e->getMessage() . "</p>";
}

// Show table structure for troubleshooting
try {
    $tables = ['users', 'duty_status'];
    
    foreach ($tables as $table) {
        echo "<h3>Table Structure: $table</h3>";
        
        $stmt = $pdo->query("DESCRIBE $table");
        $columns = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        echo "<table border='1' cellpadding='5'>";
        echo "<tr><th>Field</th><th>Type</th><th>Null</th><th>Key</th><th>Default</th></tr>";
        
        foreach ($columns as $col) {
            echo "<tr>";
            echo "<td>" . $col['Field'] . "</td>";
            echo "<td>" . $col['Type'] . "</td>";
            echo "<td>" . $col['Null'] . "</td>";
            echo "<td>" . $col['Key'] . "</td>";
            echo "<td>" . ($col['Default'] ?? 'NULL') . "</td>";
            echo "</tr>";
        }
        
        echo "</table>";
    }
} catch (PDOException $e) {
    echo "<p style='color:red'>Error getting table structure: " . $e->getMessage() . "</p>";
}
?>

<!DOCTYPE html>
<html>
<head>
    <title>Test Duty Status Update</title>
    <style>
        body { font-family: Arial, sans-serif; line-height: 1.6; padding: 20px; }
        form { margin: 20px 0; padding: 20px; border: 1px solid #ddd; border-radius: 5px; }
        input, select { margin-bottom: 10px; padding: 8px; width: 100%; }
        button { padding: 10px 15px; background: #4CAF50; color: white; border: none; cursor: pointer; }
        h2, h3 { margin-top: 20px; }
    </style>
</head>
<body>
    <h2>Test Duty Status Update</h2>
    
    <form method="post">
        <div>
            <label for="test_status_id">Select Status:</label>
            <select id="test_status_id" name="test_status_id" required>
                <option value="">-- Select Status --</option>
                <?php foreach ($statuses as $status): ?>
                <option value="<?php echo $status['id']; ?>"><?php echo $status['status_name']; ?></option>
                <?php endforeach; ?>
            </select>
        </div>
        
        <div>
            <label for="test_shift">Select Shift:</label>
            <select id="test_shift" name="test_shift">
                <option value="">-- No Shift --</option>
                <option value="D6Hours">Day - 6 Hours</option>
                <option value="D12Hours">Day - 12 Hours</option>
                <option value="D24Hours">Day - 24 Hours</option>
                <option value="N6Hours">Night - 6 Hours</option>
                <option value="N12Hours">Night - 12 Hours</option>
                <option value="N24Hours">Night - 24 Hours</option>
            </select>
        </div>
        
        <button type="submit" name="test_update">Test Update</button>
    </form>
    
    <p><a href="update-duty-status.php">Return to Duty Status Page</a></p>
</body>
</html>