<?php
// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
}

// Get user information for display
$username = $_SESSION["username"] ?? "";
$fullname = $_SESSION["fullname"] ?? "";
$role = $_SESSION["role"] ?? "";
$userId = $_SESSION["user_id"] ?? "";

// If user is admin, redirect to reports page
if ($role === 'admin') {
    echo "<script>window.location.href = 'get-reports.php';</script>";
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Thank You - Emergency Code Reported</title>
  <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
  <style>
    .code-badge {
      display: inline-block;
      padding: 0.25rem 0.75rem;
      border-radius: 9999px;
      font-weight: 600;
      text-transform: uppercase;
    }
    .code-red {
      background-color: #FF3333;
      color: white;
    }
    .code-yellow {
      background-color: #FFDC46;
      color: black;
    }
    .code-black {
      background-color: #000000;
      color: white;
    }
    .code-orange {
      background-color: #FF9966;
      color: white;
    }
  </style>
  <script>
    // Get report details from sessionStorage
    function getReportDetails() {
      try {
        const reportData = sessionStorage.getItem('lastReport');
        if (reportData) {
          return JSON.parse(reportData);
        }
      } catch (e) {
        console.error('Error parsing report data:', e);
      }
      return null;
    }
    
    // Format date nicely
    function formatDate(dateString) {
      try {
        const date = new Date(dateString);
        return date.toLocaleString();
      } catch (e) {
        return 'Unknown time';
      }
    }
    
    // Display report details when the page loads
    document.addEventListener('DOMContentLoaded', function() {
      const report = getReportDetails();
      if (report) {
        document.getElementById('report-time').textContent = formatDate(report.timestamp);
        
        const codeDisplay = document.getElementById('code-type');
        if (codeDisplay) {
          let codeType = 'Unknown';
          let codeClass = '';
          
          if (report.codeType === 'code-red') {
            codeType = 'CODE RED';
            codeClass = 'code-red';
          } else if (report.codeType === 'code-yellow') {
            codeType = 'CODE YELLOW';
            codeClass = 'code-yellow';
          } else if (report.codeType === 'code-black') {
            codeType = 'CODE BLACK';
            codeClass = 'code-black';
          } else if (report.codeType === 'code-orange') {
            codeType = 'CODE ORANGE';
            codeClass = 'code-orange';
          }
          
          codeDisplay.innerHTML = `<span class="code-badge ${codeClass}">${codeType}</span>`;
        }
        
        if (report.location) {
          document.getElementById('report-location').textContent = report.location;
        }
        
        if (report.building) {
          document.getElementById('report-building').textContent = report.building;
          document.getElementById('building-section').classList.remove('hidden');
        }
        
        if (report.details) {
          document.getElementById('report-details').textContent = report.details;
          document.getElementById('details-section').classList.remove('hidden');
        }
        
        document.getElementById('report-id').textContent = `ECR-${String(report.id).padStart(6, '0')}`;
      }
    });
  </script>
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
  <header class="bg-red-600 text-white p-4 shadow-md">
    <div class="container mx-auto flex justify-between items-center">
      <h1 class="text-2xl font-bold">Hospital Emergency Code Reporter</h1>
      <div class="flex items-center space-x-4">
        <span class="text-sm">Welcome, <?php echo htmlspecialchars($fullname); ?></span>
        <a href="index.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">New Report</a>
        <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
      </div>
    </div>
  </header>
  
  <main class="flex-grow p-4">
    <div class="container mx-auto max-w-2xl">
      <div class="bg-white rounded-lg shadow-md p-6">
        <div class="text-center mb-6">
          <div class="bg-green-100 text-green-800 inline-flex items-center px-4 py-2 rounded-full mb-4">
            <svg xmlns="http://www.w3.org/2000/svg" class="h-5 w-5 mr-2" viewBox="0 0 20 20" fill="currentColor">
              <path fill-rule="evenodd" d="M10 18a8 8 0 100-16 8 8 0 000 16zm3.707-9.293a1 1 0 00-1.414-1.414L9 10.586 7.707 9.293a1 1 0 00-1.414 1.414l2 2a1 1 0 001.414 0l4-4z" clip-rule="evenodd" />
            </svg>
            Emergency Code Reported Successfully
          </div>
          <h2 class="text-2xl font-bold">Thank You</h2>
          <p class="text-gray-600 mt-2">Your emergency code report has been submitted and is being reviewed by administrators.</p>
        </div>
        
        <div class="border-t border-gray-200 pt-4 mt-4">
          <h3 class="text-lg font-semibold mb-4">Report Details</h3>
          
          <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
            <div>
              <p class="text-sm text-gray-500">Report ID</p>
              <p class="font-medium" id="report-id">-</p>
            </div>
            <div>
              <p class="text-sm text-gray-500">Time Submitted</p>
              <p class="font-medium" id="report-time">-</p>
            </div>
            <div>
              <p class="text-sm text-gray-500">Code Type</p>
              <p class="font-medium" id="code-type">-</p>
            </div>
            <div>
              <p class="text-sm text-gray-500">Location</p>
              <p class="font-medium" id="report-location">-</p>
            </div>
            <div id="building-section" class="hidden">
              <p class="text-sm text-gray-500">Building</p>
              <p class="font-medium" id="report-building">-</p>
            </div>
          </div>
          
          <div id="details-section" class="hidden mt-4">
            <p class="text-sm text-gray-500">Additional Details</p>
            <p class="font-medium bg-gray-50 p-3 rounded" id="report-details">-</p>
          </div>
        </div>
        
        <div class="border-t border-gray-200 pt-4 mt-6">
          <div class="bg-blue-50 text-blue-800 p-4 rounded">
            <h3 class="font-semibold mb-2">What happens next?</h3>
            <p>Your report has been logged in the system and immediately announced to staff in the affected area. Hospital administrators have been notified and will review your report.</p>
            <p class="mt-2">For urgent follow-up, please contact the Emergency Response Team at extension 1234.</p>
          </div>
        </div>
        
        <div class="mt-6 text-center">
          <a href="index.php" class="bg-red-600 hover:bg-red-700 text-white font-bold py-2 px-4 rounded">
            Report Another Emergency Code
          </a>
        </div>
      </div>
    </div>
  </main>
  
  <footer class="bg-gray-800 text-white p-4 text-center text-sm">
    <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
    <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
  </footer>
</body>
</html>