// First check if user is logged in
document.addEventListener('DOMContentLoaded', function() {
  // Function to check session status
  const checkSession = async () => {
    try {
      const response = await fetch('check-session.php');
      const data = await response.json();
      
      if (!data.loggedin) {
        // User is not logged in, redirect to login page
        window.location.href = 'login.php';
        return false;
      }
      
      // User is logged in
      return true;
    } catch (error) {
      console.error('Error checking session:', error);
      // On error, assume session is invalid and redirect
      window.location.href = 'login.php';
      return false;
    }
  };
  
  // Check session and then initialize the app
  checkSession().then(sessionValid => {
    if (sessionValid) {
      // Initialize main application
      initializeApp();
    }
  });
});

function initializeApp() {
  // Main application code goes here
  // Original EmergencyCodeReporter component code
  const Card = ({ children, className }) => {
    return <div className={`bg-white rounded-lg shadow-md ${className || ''}`}>{children}</div>;
  };

  const CardHeader = ({ children }) => {
    return <div className="p-4 border-b">{children}</div>;
  };

  const CardTitle = ({ children }) => {
    return <h2 className="text-xl font-bold">{children}</h2>;
  };

  const CardContent = ({ children }) => {
    return <div className="p-4">{children}</div>;
  };

  // Main EmergencyCodeReporter component
  const EmergencyCodeReporter = () => {
    // Rest of your component code...
    
    // Remember to update the form submission code:
    const handleSubmit = async (e) => {
      e.preventDefault();
      setIsSubmitting(true);
      setError('');
      
      try {
        // Initialize audio for mobile - must happen in direct response to user action
        if (!audioContext) {
          initializeAudioContext();
        } else if (audioContext.state !== 'running') {
          try {
            await audioContext.resume();
          } catch (e) {
            console.warn("Could not resume AudioContext:", e);
          }
        }
        
        // ... rest of your audio setup code
        
        // Submit the data to MySQL database
        const result = await submitToDatabase();
        
        if (result.success) {
          // ... rest of your success handling code
        }
      } catch (err) {
        if (err.message === 'Unauthorized') {
          // Session has expired
          window.location.href = 'login.php';
          return;
        }
        
        setError('Failed to submit the emergency code. Please try again.');
      } finally {
        setIsSubmitting(false);
      }
    };
    
    // Rest of your component code...
  };

  // Render the application
  ReactDOM.render(
    <EmergencyCodeReporter />,
    document.getElementById('root')
  );
}
