<?php
// Start session
session_start();

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
} else if ($_SESSION["role"] !== "admin") {
    // Redirect non-admin users
    echo "<script>window.location.href = 'index.php';</script>";
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Get emergency codes for the filter
$emergencyCodes = [];
try {
    $stmt = $pdo->query("SELECT code_value, label, description, bg_color, text_color, priority FROM emergency_codes ORDER BY priority, label");
    $emergencyCodes = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    // Log error but continue
    error_log("Error fetching emergency codes: " . $e->getMessage());
}

// Get buildings for the filter
$buildings = [];
try {
    $stmt = $pdo->query("SELECT id, name, short_code FROM buildings WHERE active = 1 ORDER BY name");
    $buildings = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    // Log error but continue
    error_log("Error fetching buildings: " . $e->getMessage());
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Emergency Code Reports - Admin Dashboard</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <script src="https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.29.1/moment.min.js"></script>
    <style>
        /* Priority indicators */
        .priority-1 {
            border-left: 4px solid #DC2626;
        }
        .priority-2 {
            border-left: 4px solid #EA580C;
        }
        .priority-3 {
            border-left: 4px solid #D97706;
        }
        .priority-4 {
            border-left: 4px solid #65A30D;
        }
        .priority-5 {
            border-left: 4px solid #0EA5E9;
        }
        
        /* Status indicators */
        .status-active {
            animation: pulse-animation 2s infinite;
        }
        
        @keyframes pulse-animation {
            0% {
                box-shadow: 0 0 0 0 rgba(220, 38, 38, 0.5);
            }
            70% {
                box-shadow: 0 0 0 10px rgba(220, 38, 38, 0);
            }
            100% {
                box-shadow: 0 0 0 0 rgba(220, 38, 38, 0);
            }
        }
        
        /* Draggable modal */
        .draggable-header {
            cursor: move;
        }
    </style>
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">Hospital Emergency Code Reports</h1>
            <div class="flex items-center space-x-4">
                <a href="user-manager.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Manage Users</a>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($_SESSION["fullname"] ?? 'Admin'); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto">
            <div class="bg-white rounded-lg shadow p-6">
                <div class="flex flex-col md:flex-row justify-between items-start md:items-center mb-6 space-y-4 md:space-y-0">
                    <h2 class="text-xl font-bold text-gray-800">Emergency Reports</h2>
                    <div class="flex flex-wrap gap-2">
                        <a href="index.php" class="bg-red-500 hover:bg-red-600 text-white px-4 py-2 rounded">
                            New Report
                        </a>
                        <div class="flex space-x-2">
                            <select id="code-filter" class="border border-gray-300 rounded px-3 py-1 focus:outline-none focus:ring-2 focus:ring-red-500">
                                <option value="">All Codes</option>
                                <?php foreach ($emergencyCodes as $code): ?>
                                <option value="<?php echo htmlspecialchars($code['code_value']); ?>">
                                    <?php echo htmlspecialchars($code['label']); ?>
                                </option>
                                <?php endforeach; ?>
                            </select>
                            
                            <select id="building-filter" class="border border-gray-300 rounded px-3 py-1 focus:outline-none focus:ring-2 focus:ring-red-500">
                                <option value="">All Buildings</option>
                                <?php foreach ($buildings as $building): ?>
                                <option value="<?php echo htmlspecialchars($building['id']); ?>">
                                    <?php echo htmlspecialchars($building['name']); ?> (<?php echo htmlspecialchars($building['short_code']); ?>)
                                </option>
                                <?php endforeach; ?>
                            </select>
                            
                            <select id="status-filter" class="border border-gray-300 rounded px-3 py-1 focus:outline-none focus:ring-2 focus:ring-red-500">
                                <option value="">All Reports</option>
                                <option value="active">Active</option>
                                <option value="resolved">Resolved</option>
                                <option value="false_alarm">False Alarm</option>
                            </select>
                            
                            <button id="refresh-btn" class="bg-blue-500 hover:bg-blue-600 text-white px-3 py-1 rounded flex items-center">
                                <svg xmlns="http://www.w3.org/2000/svg" class="h-4 w-4 mr-1" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M4 4v5h.582m15.356 2A8.001 8.001 0 004.582 9m0 0H9m11 11v-5h-.581m0 0a8.003 8.003 0 01-15.357-2m15.357 2H15" />
                                </svg>
                                Refresh
                            </button>
                        </div>
                    </div>
                </div>
                
                <div id="active-reports-container" class="mb-8">
                    <h3 class="text-lg font-bold text-red-600 mb-4 flex items-center">
                        <svg xmlns="http://www.w3.org/2000/svg" class="h-5 w-5 mr-2" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z" />
                        </svg>
                        Active Emergency Reports
                    </h3>
                    <div id="active-reports" class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
                        <div class="col-span-full text-center py-4 text-gray-500">Loading active reports...</div>
                    </div>
                </div>
                
                <div class="overflow-x-auto">
                    <table class="min-w-full divide-y divide-gray-200">
                        <thead class="bg-gray-50">
                            <tr>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Report ID</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Code</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Location</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Reported By</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Time</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Status</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
                            </tr>
                        </thead>
                        <tbody id="reports-table-body" class="bg-white divide-y divide-gray-200">
                            <tr>
                                <td colspan="7" class="px-6 py-4 text-center text-gray-500">Loading reports...</td>
                            </tr>
                        </tbody>
                    </table>
                </div>
                
                <div class="mt-4 flex justify-between items-center">
                    <div class="text-sm text-gray-500" id="reports-count">
                        Loading...
                    </div>
                    <div class="flex space-x-2">
                        <button id="prev-page" class="px-3 py-1 border border-gray-300 rounded disabled:opacity-50">
                            Previous
                        </button>
                        <button id="next-page" class="px-3 py-1 border border-gray-300 rounded disabled:opacity-50">
                            Next
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
    
    <!-- Report details modal -->
    <div id="report-modal" class="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center hidden">
        <div class="bg-white rounded-lg max-w-2xl w-full p-6 max-h-screen overflow-auto" id="modal-content">
            <div class="flex justify-between items-center mb-4 draggable-header cursor-move" id="modal-header">
                <h3 class="text-xl font-bold" id="modal-title">Report Details</h3>
                <button id="close-modal" class="text-gray-500 hover:text-gray-700">
                    <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12"></path>
                    </svg>
                </button>
            </div>
            <div id="modal-body">
                <!-- Report details will be loaded here -->
            </div>
            <div class="mt-4 pt-4 border-t border-gray-200">
                <h4 class="font-bold mb-2">Update Status</h4>
                <div class="flex space-x-2">
                    <select id="status-update" class="border border-gray-300 rounded px-3 py-2 focus:outline-none focus:ring-2 focus:ring-red-500 flex-grow">
                        <option value="active">Active</option>
                        <option value="resolved">Resolved</option>
                        <option value="false_alarm">False Alarm</option>
                    </select>
                    <button id="update-status-btn" class="bg-green-500 hover:bg-green-600 text-white px-4 py-2 rounded" data-report-id="">
                        Update
                    </button>
                </div>
            </div>
        </div>
    </div>
    
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // DOM elements
            const reportsTableBody = document.getElementById('reports-table-body');
            const activeReportsContainer = document.getElementById('active-reports');
            const reportsCount = document.getElementById('reports-count');
            const prevPageBtn = document.getElementById('prev-page');
            const nextPageBtn = document.getElementById('next-page');
            const codeFilter = document.getElementById('code-filter');
            const buildingFilter = document.getElementById('building-filter');
            const statusFilter = document.getElementById('status-filter');
            const refreshBtn = document.getElementById('refresh-btn');
            const reportModal = document.getElementById('report-modal');
            const closeModalBtn = document.getElementById('close-modal');
            const modalContent = document.getElementById('modal-content');
            const modalBody = document.getElementById('modal-body');
            const modalTitle = document.getElementById('modal-title');
            const statusUpdate = document.getElementById('status-update');
            const updateStatusBtn = document.getElementById('update-status-btn');
            const modalHeader = document.getElementById('modal-header');
            
            // Variables for pagination
            let currentOffset = 0;
            const limit = 10;
            let totalReports = 0;
            let currentCodeFilter = '';
            let currentBuildingFilter = '';
            let currentStatusFilter = '';
            
            // Make modal draggable
            let isDragging = false;
            let currentX;
            let currentY;
            let initialX;
            let initialY;
            let xOffset = 0;
            let yOffset = 0;
            
            modalHeader.addEventListener("mousedown", dragStart);
            document.addEventListener("mouseup", dragEnd);
            document.addEventListener("mousemove", drag);
            
            function dragStart(e) {
                initialX = e.clientX - xOffset;
                initialY = e.clientY - yOffset;
                
                if (e.target === modalHeader || modalHeader.contains(e.target)) {
                    isDragging = true;
                }
            }
            
            function dragEnd(e) {
                initialX = currentX;
                initialY = currentY;
                isDragging = false;
            }
            
            function drag(e) {
                if (isDragging) {
                    e.preventDefault();
                    currentX = e.clientX - initialX;
                    currentY = e.clientY - initialY;
                    
                    xOffset = currentX;
                    yOffset = currentY;
                    
                    setTranslate(currentX, currentY, modalContent);
                }
            }
            
            function setTranslate(xPos, yPos, el) {
                el.style.transform = `translate3d(${xPos}px, ${yPos}px, 0)`;
            }
            
            // Format date function
            const formatDate = (dateString) => {
                return moment(dateString).format('MMM D, YYYY, h:mm A');
            };
            
            // Format time ago
            const formatTimeAgo = (dateString) => {
                return moment(dateString).fromNow();
            };
            
            // Function to get status badge HTML
            const getStatusBadge = (status) => {
                let color = '';
                let label = '';
                switch(status) {
                    case 'active':
                        color = 'bg-red-100 text-red-800';
                        label = 'ACTIVE';
                        break;
                    case 'resolved':
                        color = 'bg-green-100 text-green-800';
                        label = 'RESOLVED';
                        break;
                    case 'false_alarm':
                        color = 'bg-gray-100 text-gray-800';
                        label = 'FALSE ALARM';
                        break;
                    default:
                        color = 'bg-blue-100 text-blue-800';
                        label = status.replace('_', ' ').toUpperCase();
                }
                
                return `<span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full ${color}">
                    ${label}
                </span>`;
            };
            
            // Get background color for code
            const getCodeBadge = (code, codeValue) => {
                // Find the code in our emergency codes array
                const codeInfo = <?php echo json_encode($emergencyCodes); ?>;
                const foundCode = codeInfo.find(c => c.code_value === codeValue);
                
                if (foundCode) {
                    return `<span class="px-2 py-1 rounded" style="background-color: ${foundCode.bg_color}; color: ${foundCode.text_color}">
                        ${code}
                    </span>`;
                }
                
                return `<span class="px-2 py-1 rounded bg-gray-200">${code}</span>`;
            };
            
            // Load reports from API
            const loadReports = async () => {
                try {
                    // Show loading state
                    reportsTableBody.innerHTML = `
                        <tr>
                            <td colspan="7" class="px-6 py-4 text-center text-gray-500">Loading reports...</td>
                        </tr>
                    `;
                    
                    // Fetch data from API
                    let url = `get-reports.php?api=true&limit=${limit}&offset=${currentOffset}`;
                    if (currentStatusFilter) {
                        url += `&status=${currentStatusFilter}`;
                    }
                    if (currentCodeFilter) {
                        url += `&code=${currentCodeFilter}`;
                    }
                    if (currentBuildingFilter) {
                        url += `&building=${currentBuildingFilter}`;
                    }
                    
                    const response = await fetch(url);
                    const data = await response.json();
                    
                    if (!data.success) {
                        throw new Error(data.message || 'Failed to load reports');
                    }
                    
                    totalReports = data.pagination.total;
                    
                    // Update reports count
                    reportsCount.textContent = `Showing ${Math.min(data.reports.length, limit)} of ${totalReports} reports`;
                    
                    // Update pagination buttons
                    prevPageBtn.disabled = currentOffset === 0;
                    nextPageBtn.disabled = !data.pagination.hasMore;
                    
                    // Render reports
                    if (data.reports.length === 0) {
                        reportsTableBody.innerHTML = `
                            <tr>
                                <td colspan="7" class="px-6 py-4 text-center text-gray-500">No reports found</td>
                            </tr>
                        `;
                        return;
                    }
                    
                    reportsTableBody.innerHTML = data.reports.map(report => {
                        const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
                        const priorityClass = report.priority ? `priority-${report.priority}` : '';
                        
                        return `
                        <tr class="${priorityClass} ${report.status === 'active' ? 'bg-red-50' : ''}">
                            <td class="px-6 py-4 whitespace-nowrap font-bold text-blue-600">${formattedRefId}</td>
                            <td class="px-6 py-4 whitespace-nowrap">
                                ${getCodeBadge(report.code_label, report.code_id)}
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap">${report.location}</td>
                            <td class="px-6 py-4 whitespace-nowrap">${report.reported_by}</td>
                            <td class="px-6 py-4 whitespace-nowrap" title="${formatDate(report.report_time)}">
                                ${formatTimeAgo(report.report_time)}
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap">${getStatusBadge(report.status)}</td>
                            <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                                <button 
                                    class="text-indigo-600 hover:text-indigo-900 view-details"
                                    data-report-id="${report.id}"
                                    data-report='${JSON.stringify(report)}'
                                >
                                    View Details
                                </button>
                            </td>
                        </tr>
                        `;
                    }).join('');
                    
                    // Add event listeners to view details buttons
                    document.querySelectorAll('.view-details').forEach(button => {
                        button.addEventListener('click', function() {
                            try {
                                const reportData = JSON.parse(this.getAttribute('data-report'));
                                showReportDetails(reportData);
                            } catch (e) {
                                console.error("Error parsing report data:", e);
                                alert("Error displaying report details");
                            }
                        });
                    });
                    
                    // Load active reports for the cards at the top
                    loadActiveReports();
                    
                } catch (error) {
                    console.error('Error loading reports:', error);
                    reportsTableBody.innerHTML = `
                        <tr>
                            <td colspan="7" class="px-6 py-4 text-center text-red-500">
                                Error loading reports: ${error.message}
                            </td>
                        </tr>
                    `;
                }
            };
            
            // Load active reports for cards
            const loadActiveReports = async () => {
                try {
                    // Show loading state
                    activeReportsContainer.innerHTML = `<div class="col-span-full text-center py-4 text-gray-500">Loading active reports...</div>`;
                    
                    // Fetch active reports only
                    let url = `get-reports.php?api=true&limit=6&status=active`;
                    if (currentCodeFilter) {
                        url += `&code=${currentCodeFilter}`;
                    }
                    if (currentBuildingFilter) {
                        url += `&building=${currentBuildingFilter}`;
                    }
                    
                    const response = await fetch(url);
                    const data = await response.json();
                    
                    if (!data.success) {
                        throw new Error(data.message || 'Failed to load active reports');
                    }
                    
                    // Render active reports as cards
                    if (data.reports.length === 0) {
                        activeReportsContainer.innerHTML = `<div class="col-span-full text-center py-4 text-gray-500">No active emergency reports</div>`;
                        return;
                    }
                    
                    activeReportsContainer.innerHTML = data.reports.map(report => {
                        const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
                        const priorityClass = report.priority ? `priority-${report.priority}` : '';
                        
                        return `
                        <div class="bg-white rounded-lg shadow-md overflow-hidden ${priorityClass} status-active">
                            <div class="p-4">
                                <div class="flex justify-between items-start">
                                    <div>
                                        <h4 class="font-bold text-lg">
                                            ${getCodeBadge(report.code_label, report.code_id)}
                                        </h4>
                                        <p class="text-sm text-gray-600 mt-1">${formattedRefId}</p>
                                    </div>
                                    <span class="bg-red-100 text-red-800 px-2 py-1 rounded-full text-xs font-bold animate-pulse">ACTIVE</span>
                                </div>
                                
                                <div class="mt-4">
                                    <p class="text-gray-700"><strong>Location:</strong> ${report.location}</p>
                                    <p class="text-gray-700"><strong>Reported by:</strong> ${report.reported_by}</p>
                                    <p class="text-gray-700"><strong>Time:</strong> ${formatTimeAgo(report.report_time)}</p>
                                    
                                    ${report.details ? `<p class="text-gray-700 mt-2"><strong>Details:</strong> ${report.details}</p>` : ''}
                                    
                                    ${report.estimated_response_time ? 
                                        `<p class="text-red-600 font-bold mt-2">Est. Response: ${report.estimated_response_time} min</p>` : 
                                        ''}
                                </div>
                                
                                <div class="mt-4 flex justify-end">
                                    <button 
                                        class="bg-indigo-500 hover:bg-indigo-600 text-white px-3 py-1 rounded text-sm view-details"
                                        data-report-id="${report.id}"
                                        data-report='${JSON.stringify(report)}'
                                    >
                                        View Details
                                    </button>
                                </div>
                            </div>
                        </div>
                        `;
                    }).join('');
                    
                    // Add event listeners to view details buttons in active reports
                    document.querySelectorAll('.view-details').forEach(button => {
                        button.addEventListener('click', function() {
                            try {
                                const reportData = JSON.parse(this.getAttribute('data-report'));
                                showReportDetails(reportData);
                            } catch (e) {
                                console.error("Error parsing report data:", e);
                                alert("Error displaying report details");
                            }
                        });
                    });
                    
                } catch (error) {
                    console.error('Error loading active reports:', error);
                    activeReportsContainer.innerHTML = `
                        <div class="col-span-full text-center py-4 text-red-500">
                            Error loading active reports: ${error.message}
                        </div>
                    `;
                }
            };
            
            // Show report details in modal
            const showReportDetails = (report) => {
                modalTitle.textContent = `${report.code_label} Report`;
                
                const formattedRefId = report.formatted_reference_id || `ECR-${String(report.id).padStart(6, '0')}`;
                
                modalBody.innerHTML = `
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div>
                            <p class="text-gray-500 text-sm">Report ID</p>
                            <p class="font-medium text-blue-600">${formattedRefId}</p>
                        </div>
                        <div>
                            <p class="text-gray-500 text-sm">Code</p>
                            <p class="font-medium">${getCodeBadge(report.code_label, report.code_id)}</p>
                        </div>
                        <div>
                            <p class="text-gray-500 text-sm">Location</p>
                            <p class="font-medium">${report.location}</p>
                        </div>
                        <div>
                            <p class="text-gray-500 text-sm">Reported By</p>
                            <p class="font-medium">${report.reported_by}</p>
                        </div>
                        <div>
                            <p class="text-gray-500 text-sm">Time</p>
                            <p class="font-medium">${formatDate(report.report_time)}</p>
                        </div>
                        <div>
                            <p class="text-gray-500 text-sm">Status</p>
                            <p class="font-medium">${getStatusBadge(report.status)}</p>
                        </div>
                        ${report.estimated_response_time ? `
                        <div>
                            <p class="text-gray-500 text-sm">Est. Response Time</p>
                            <p class="font-medium text-red-600">${report.estimated_response_time} minutes</p>
                        </div>
                        ` : ''}
                        <div class="col-span-2">
                            <p class="text-gray-500 text-sm">Details</p>
                            <p class="font-medium">${report.details || 'No additional details provided'}</p>
                        </div>
                    </div>
                    
                    <div class="mt-4 pt-4 border-t border-gray-200">
                        <h4 class="font-bold mb-2">Status Notes</h4>
                        <textarea id="status-notes" class="w-full px-3 py-2 border border-gray-300 rounded-md" 
                                  rows="2" placeholder="Add notes about this status change (optional)"></textarea>
                    </div>
                    
                    ${report.audio_file ? `
                    <div class="mt-4 pt-4 border-t border-gray-200">
                        <h4 class="font-bold mb-2">Announcement Audio</h4>
                        <audio controls class="w-full">
                            <source src="${report.audio_file}" type="audio/mp3">
                            Your browser does not support the audio element.
                        </audio>
                    </div>
                    ` : ''}
                    
                    ${report.text_to_audio ? `
                    <div class="mt-4 pt-4 border-t border-gray-200">
                        <h4 class="font-bold mb-2">Announcement Text</h4>
                        <p class="p-2 bg-gray-100 rounded">${report.text_to_audio}</p>
                    </div>
                    ` : ''}
                `;
                
                // Reset modal position
                xOffset = 0;
                yOffset = 0;
                modalContent.style.transform = '';
                
                // Set current status in the dropdown
                statusUpdate.value = report.status;
                
                // Set report ID for the update button
                updateStatusBtn.setAttribute('data-report-id', report.id);
                
                // Show modal
                reportModal.classList.remove('hidden');
            };
            
            // Event Listeners
            codeFilter.addEventListener('change', function() {
                currentCodeFilter = this.value;
                currentOffset = 0;
                loadReports();
            });
            
            buildingFilter.addEventListener('change', function() {
                currentBuildingFilter = this.value;
                currentOffset = 0;
                loadReports();
            });
            
            statusFilter.addEventListener('change', function() {
                currentStatusFilter = this.value;
                currentOffset = 0;
                loadReports();
            });
            
            refreshBtn.addEventListener('click', loadReports);
            
            prevPageBtn.addEventListener('click', function() {
                if (currentOffset >= limit) {
                    currentOffset -= limit;
                    loadReports();
                }
            });
            
            nextPageBtn.addEventListener('click', function() {
                currentOffset += limit;
                loadReports();
            });
            
            closeModalBtn.addEventListener('click', function() {
                reportModal.classList.add('hidden');
            });
            
            updateStatusBtn.addEventListener('click', async function() {
                const reportId = this.getAttribute('data-report-id');
                const newStatus = statusUpdate.value;
                const statusNotes = document.getElementById('status-notes').value;
                
                // Show loading state
                updateStatusBtn.disabled = true;
                updateStatusBtn.textContent = 'Updating...';
                
                try {
                    // Send status update request to the server
                    const response = await fetch('update-status.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/json',
                        },
                        body: JSON.stringify({
                            report_id: reportId,
                            status: newStatus,
                            notes: statusNotes
                        })
                    });
                    
                    const result = await response.json();
                    
                    if (!result.success) {
                        throw new Error(result.error || 'Failed to update status');
                    }
                    
                    // Show success message
                    alert(`Status successfully updated to ${newStatus.toUpperCase()}`);
                    
                    // Close the modal
                    reportModal.classList.add('hidden');
                    
                    // Refresh reports
                    loadReports();
                } catch (error) {
                    console.error('Error updating status:', error);
                    alert('Failed to update status: ' + error.message);
                } finally {
                    // Reset button state
                    updateStatusBtn.disabled = false;
                    updateStatusBtn.textContent = 'Update';
                }
            });
            
            // Close modal when clicking outside the content
            reportModal.addEventListener('click', function(event) {
                if (event.target === reportModal) {
                    reportModal.classList.add('hidden');
                }
            });
            
            // Set up auto-refresh for active reports
            setInterval(() => {
                if (document.visibilityState === 'visible') {
                    loadActiveReports();
                }
            }, 30000); // Refresh every 30 seconds
            
            // Initial load
            loadReports();
        });
    </script>
</body>
</html>