<?php
session_start();
require_once '../db-connection.php';

header('Content-Type: application/json');

// Check if user is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true || $_SESSION["role"] !== "admin") {
    echo json_encode(['success' => false, 'message' => 'Unauthorized access']);
    exit;
}

// Get form data
$username = trim($_POST["username"]);
$password = trim($_POST["password"]);
$fullname = trim($_POST["fullname"]);
$email = trim($_POST["email"] ?? '');
$role = trim($_POST["role"]);
$emp_id = trim($_POST["emp_id"] ?? '');

// Basic validation
if (empty($username) || empty($password) || empty($fullname) || empty($role)) {
    echo json_encode(['success' => false, 'message' => 'Please fill all required fields']);
    exit;
}

try {
    // Check if username exists
    $check_sql = "SELECT id FROM users WHERE username = ?";
    $check_stmt = $pdo->prepare($check_sql);
    $check_stmt->execute([$username]);
    
    if ($check_stmt->rowCount() > 0) {
        echo json_encode(['success' => false, 'message' => 'Username already exists']);
        exit;
    }
    
    // Create user
    $hashed_password = password_hash($password, PASSWORD_DEFAULT);
    
    $sql = "INSERT INTO users (username, password, fullname, email, role, emp_id) VALUES (?, ?, ?, ?, ?, ?)";
    $stmt = $pdo->prepare($sql);
    $stmt->execute([$username, $hashed_password, $fullname, $email, $role, $emp_id]);
    
    echo json_encode(['success' => true, 'message' => 'User created successfully']);
} catch (PDOException $e) {
    echo json_encode(['success' => false, 'message' => 'Database error: ' . $e->getMessage()]);
}