<?php
// Place this in a file called debug-duty-status.php
// It will help diagnose exactly what's happening with your form submission

// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    echo "Not logged in";
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Get user information
$userId = $_SESSION["user_id"] ?? 0;
$fullname = $_SESSION["fullname"] ?? "User";

echo "<h1>Duty Status Debug Tool</h1>";
echo "<p>User ID: $userId, Name: $fullname</p>";
echo "<hr>";

echo "<h2>Form Data</h2>";
echo "<pre>";
print_r($_POST);
echo "</pre>";
echo "<hr>";

// Check user record in database
echo "<h2>Current User Record</h2>";
try {
    $stmt = $pdo->prepare("SELECT * FROM users WHERE id = ?");
    $stmt->execute([$userId]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);
    
    echo "<pre>";
    print_r($user);
    echo "</pre>";
} catch (PDOException $e) {
    echo "Error: " . $e->getMessage();
}
echo "<hr>";

// Check duty_status table
echo "<h2>Available Duty Statuses</h2>";
try {
    $stmt = $pdo->query("SELECT * FROM duty_status");
    $statuses = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<table border='1' cellpadding='5'>";
    echo "<tr><th>ID</th><th>Status Name</th><th>Description</th></tr>";
    foreach ($statuses as $status) {
        echo "<tr>";
        echo "<td>" . $status['id'] . "</td>";
        echo "<td>" . $status['status_name'] . "</td>";
        echo "<td>" . $status['description'] . "</td>";
        echo "</tr>";
    }
    echo "</table>";
} catch (PDOException $e) {
    echo "Error: " . $e->getMessage();
}
echo "<hr>";

// Test direct database updates
echo "<h2>Test Database Update</h2>";

if (isset($_GET['test_update']) && $_GET['test_update'] === 'true') {
    try {
        $newStatusId = $_GET['status_id'] ?? 2; // Default to status ID 2 if not specified
        $newShift = $_GET['shift'] ?? 'D6Hours'; // Default shift
        
        echo "<p>Attempting to update user $userId to status ID $newStatusId with shift $newShift</p>";
        
        // Try the update
        $stmt = $pdo->prepare("UPDATE users SET duty_status_id = ?, duty_shift = ? WHERE id = ?");
        $stmt->execute([$newStatusId, $newShift, $userId]);
        
        echo "<p>Update result: " . $stmt->rowCount() . " rows affected</p>";
        
        // If successful, try to log
        if ($stmt->rowCount() > 0) {
            // Get status name
            $getStatusName = $pdo->prepare("SELECT status_name FROM duty_status WHERE id = ?");
            $getStatusName->execute([$newStatusId]);
            $statusName = $getStatusName->fetchColumn();
            
            // Try to log
            $logStmt = $pdo->prepare("INSERT INTO status_logs (user_id, status_change, notes, change_timestamp) 
                                   VALUES (?, ?, ?, NOW())");
            $result = $logStmt->execute([
                $userId, 
                "Changed to $statusName ($newShift)", 
                "Status updated via debug script"
            ]);
            
            echo "<p>Log insertion result: " . ($result ? "Success" : "Failed") . "</p>";
            echo "<p>Log rows affected: " . $logStmt->rowCount() . "</p>";
        }
    } catch (PDOException $e) {
        echo "<p>Error: " . $e->getMessage() . "</p>";
    }
}

// Show status logs
echo "<h2>Status Logs</h2>";
try {
    $logStmt = $pdo->prepare("
        SELECT * 
        FROM status_logs 
        WHERE user_id = ? 
        ORDER BY change_timestamp DESC
        LIMIT 10
    ");
    $logStmt->execute([$userId]);
    $logs = $logStmt->fetchAll(PDO::FETCH_ASSOC);
    
    if (count($logs) > 0) {
        echo "<table border='1' cellpadding='5'>";
        echo "<tr><th>ID</th><th>Status Change</th><th>Notes</th><th>Timestamp</th></tr>";
        foreach ($logs as $log) {
            echo "<tr>";
            echo "<td>" . $log['id'] . "</td>";
            echo "<td>" . $log['status_change'] . "</td>";
            echo "<td>" . $log['notes'] . "</td>";
            echo "<td>" . $log['change_timestamp'] . "</td>";
            echo "</tr>";
        }
        echo "</table>";
    } else {
        echo "<p>No status logs found.</p>";
    }
} catch (PDOException $e) {
    echo "Error fetching logs: " . $e->getMessage();
}
echo "<hr>";

// Show raw SQL structure of tables
echo "<h2>Table Structure</h2>";

// Users table
echo "<h3>Users Table</h3>";
try {
    $stmt = $pdo->query("DESCRIBE users");
    $columns = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<table border='1' cellpadding='5'>";
    echo "<tr><th>Field</th><th>Type</th><th>Null</th><th>Key</th><th>Default</th><th>Extra</th></tr>";
    foreach ($columns as $col) {
        echo "<tr>";
        echo "<td>" . $col['Field'] . "</td>";
        echo "<td>" . $col['Type'] . "</td>";
        echo "<td>" . $col['Null'] . "</td>";
        echo "<td>" . $col['Key'] . "</td>";
        echo "<td>" . $col['Default'] . "</td>";
        echo "<td>" . ($col['Extra'] ?? '') . "</td>";
        echo "</tr>";
    }
    echo "</table>";
} catch (PDOException $e) {
    echo "Error: " . $e->getMessage();
}

// Status logs table
echo "<h3>Status Logs Table</h3>";
try {
    $stmt = $pdo->query("DESCRIBE status_logs");
    $columns = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<table border='1' cellpadding='5'>";
    echo "<tr><th>Field</th><th>Type</th><th>Null</th><th>Key</th><th>Default</th><th>Extra</th></tr>";
    foreach ($columns as $col) {
        echo "<tr>";
        echo "<td>" . $col['Field'] . "</td>";
        echo "<td>" . $col['Type'] . "</td>";
        echo "<td>" . $col['Null'] . "</td>";
        echo "<td>" . $col['Key'] . "</td>";
        echo "<td>" . $col['Default'] . "</td>";
        echo "<td>" . ($col['Extra'] ?? '') . "</td>";
        echo "</tr>";
    }
    echo "</table>";
} catch (PDOException $e) {
    echo "Error: " . $e->getMessage();
}

// Form to test update
echo "<h2>Test Update Form</h2>";
echo "<form method='get'>";
echo "<input type='hidden' name='test_update' value='true'>";
echo "<label>Status ID: <select name='status_id'>";
foreach ($statuses as $status) {
    echo "<option value='" . $status['id'] . "'>" . $status['status_name'] . "</option>";
}
echo "</select></label><br><br>";

echo "<label>Shift: <select name='shift'>";
echo "<option value='D6Hours'>Day - 6 Hours</option>";
echo "<option value='D12Hours'>Day - 12 Hours</option>";
echo "<option value='D24Hours'>Day - 24 Hours</option>";
echo "<option value='N6Hours'>Night - 6 Hours</option>";
echo "<option value='N12Hours'>Night - 12 Hours</option>";
echo "<option value='N24Hours'>Night - 24 Hours</option>";
echo "</select></label><br><br>";

echo "<button type='submit'>Test Update</button>";
echo "</form>";
?>