<?php
// This is a modified version of update-duty-status.php
// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
}

// Get user information
$userId = $_SESSION["user_id"] ?? 0;
$fullname = $_SESSION["fullname"] ?? "User";
$role = $_SESSION["role"] ?? "reporter";

// Get target user ID (from query parameter or from session if updating own status)
$targetUserId = isset($_GET['user_id']) ? (int)$_GET['user_id'] : $userId;

// Check permissions - only admins can update other users' statuses
if ($targetUserId != $userId && $role !== "admin") {
    echo "<script>window.location.href = 'index.php';</script>";
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Initialize messages
$successMessage = '';
$errorMessage = '';

// Get target user information
try {
    $userStmt = $pdo->prepare("SELECT fullname FROM users WHERE id = ?");
    $userStmt->execute([$targetUserId]);
    $targetUser = $userStmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$targetUser) {
        echo "<script>alert('User not found'); window.location.href = 'user-manager.php';</script>";
        exit;
    }
    
    $targetFullname = $targetUser['fullname'];
} catch (PDOException $e) {
    $errorMessage = "Error fetching user data: " . $e->getMessage();
    $targetFullname = "User";
}

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_status'])) {
    $newStatusId = (int)$_POST['duty_status'];
    $shift = $_POST['shift'] ?? null;
    
    try {
        // Update the user's duty status
        $stmt = $pdo->prepare("UPDATE users SET duty_status_id = ?, duty_shift = ? WHERE id = ?");
        $stmt->execute([$newStatusId, $shift, $targetUserId]);
        
        if ($stmt->rowCount() > 0) {
            $successMessage = "Duty status has been updated successfully.";
            
            // Log the status change
            $getStatusName = $pdo->prepare("SELECT status_name FROM duty_status WHERE id = ?");
            $getStatusName->execute([$newStatusId]);
            $statusName = $getStatusName->fetchColumn();
            
            $logStmt = $pdo->prepare("INSERT INTO status_logs (user_id, status_change, notes, change_timestamp) 
                                       VALUES (?, ?, ?, NOW())");
            $logStmt->execute([
                $targetUserId, 
                "Changed to $statusName ($shift)", 
                "Status updated by " . ($targetUserId == $userId ? "self" : $_SESSION["fullname"])
            ]);
        } else {
            $errorMessage = "No changes were made.";
        }
    } catch (PDOException $e) {
        $errorMessage = "Error updating status: " . $e->getMessage();
    }
}

// Get current user status
try {
    $stmt = $pdo->prepare("
        SELECT u.duty_status_id, u.duty_shift, d.status_name, d.description
        FROM users u
        LEFT JOIN duty_status d ON u.duty_status_id = d.id
        WHERE u.id = ?
    ");
    $stmt->execute([$targetUserId]);
    $currentStatus = $stmt->fetch(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $errorMessage = "Error fetching user status: " . $e->getMessage();
    $currentStatus = null;
}

// Get all available duty statuses
try {
    $stmt = $pdo->query("SELECT id, status_name, description FROM duty_status ORDER BY id");
    $dutyStatuses = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $errorMessage = "Error fetching duty statuses: " . $e->getMessage();
    $dutyStatuses = [];
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Update Duty Status - Emergency Code System</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <link href="css/duty-status.css" rel="stylesheet">
    <!-- Add favicon link -->
    <link rel="icon" href="favicon.ico" type="image/x-icon">
    <style>
        .status-badge {
            display: inline-flex;
            align-items: center;
            padding: 0.5rem 0.75rem;
            font-weight: 600;
            border-radius: 9999px;
        }
        .status-on-duty {
            background-color: #10B981;
            color: white;
        }
        .status-on-call {
            background-color: #F59E0B;
            color: white;
        }
        .status-on-leave, .status-sick-leave {
            background-color: #EF4444;
            color: white;
        }
        .status-unknown {
            background-color: #6B7280;
            color: white;
        }
        .status-card {
            transition: all 0.3s ease;
        }
        .status-card:hover {
            transform: translateY(-2px);
            box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
        }
    </style>
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">Update Duty Status</h1>
            <div class="flex items-center space-x-4">
                <a href="<?php echo $role === 'admin' ? 'user-manager.php' : 'index.php'; ?>" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">
                    <i class="fas fa-arrow-left mr-1"></i> Back
                </a>
                <a href="index.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Home</a>
                <a href="my-reports.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">My Reports</a>
                <?php if ($role === 'admin'): ?>
                <a href="get-reports.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">All Reports</a>
                <?php endif; ?>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($fullname); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto max-w-2xl">
            <?php if (!empty($successMessage)): ?>
                <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-4" role="alert">
                    <p><?php echo $successMessage; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if (!empty($errorMessage)): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
                    <p><?php echo $errorMessage; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="bg-white rounded-lg shadow p-6">
                <div class="flex items-center mb-6">
                    <div class="bg-blue-100 p-3 rounded-full mr-4">
                        <i class="fas fa-user-clock text-blue-500 text-xl"></i>
                    </div>
                    <div>
                        <h2 class="text-xl font-bold"><?php echo htmlspecialchars($targetFullname); ?></h2>
                        <p class="text-gray-600">Update duty status</p>
                    </div>
                </div>
                
                <h2 class="text-xl font-bold mb-6">Current Duty Status</h2>
                
                <div class="mb-8 p-4 bg-gray-50 rounded-lg status-card">
                    <?php if ($currentStatus && $currentStatus['duty_status_id']): ?>
                        <div class="flex items-center justify-between">
                            <div>
                                <p class="text-lg font-semibold">
                                    <?php echo htmlspecialchars($currentStatus['status_name'] ?? 'Not Set'); ?>
                                </p>
                                <p class="text-gray-600">
                                    <?php echo htmlspecialchars($currentStatus['description'] ?? ''); ?>
                                </p>
                                <?php if ($currentStatus['duty_shift']): ?>
                                    <p class="mt-1 text-sm text-gray-500">
                                        Shift: <?php echo htmlspecialchars($currentStatus['duty_shift']); ?>
                                    </p>
                                <?php endif; ?>
                            </div>
                            <div>
                                <?php 
                                // Show different status indicators based on status
                                $statusClass = 'status-unknown';
                                $statusIcon = '<i class="fas fa-question-circle mr-1"></i>';
                                
                                if ($currentStatus['status_name'] === 'OnDuty') {
                                    $statusClass = 'status-on-duty';
                                    $statusIcon = '<i class="fas fa-check-circle mr-1"></i>';
                                } elseif ($currentStatus['status_name'] === 'OnCall') {
                                    $statusClass = 'status-on-call';
                                    $statusIcon = '<i class="fas fa-phone-alt mr-1"></i>';
                                } elseif ($currentStatus['status_name'] === 'OnLeave' || $currentStatus['status_name'] === 'SickLeave') {
                                    $statusClass = 'status-on-leave';
                                    $statusIcon = '<i class="fas fa-times-circle mr-1"></i>';
                                }
                                ?>
                                <span class="status-badge <?php echo $statusClass; ?>">
                                    <?php echo $statusIcon; ?> 
                                    <?php echo htmlspecialchars($currentStatus['status_name'] ?? 'Unknown'); ?>
                                </span>
                            </div>
                        </div>
                    <?php else: ?>
                        <p class="text-gray-500">No status set. Please update the duty status below.</p>
                    <?php endif; ?>
                </div>
                
                <h3 class="text-lg font-bold mb-4">Update Status</h3>
                
                <form method="post" action="" id="duty-status-form" class="status-form">
                    <div class="mb-4">
                        <label for="duty_status" class="block text-gray-700 font-medium mb-2">Select Status:</label>
                        <select id="duty_status" name="duty_status" class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500" required>
                            <option value="">-- Select Duty Status --</option>
                            <?php foreach ($dutyStatuses as $status): ?>
                                <option value="<?php echo $status['id']; ?>" <?php echo ($currentStatus && $currentStatus['duty_status_id'] == $status['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($status['status_name']); ?> - <?php echo htmlspecialchars($status['description']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div class="mb-6">
                        <label for="shift" class="block text-gray-700 font-medium mb-2">Select Shift:</label>
                        <select id="shift" name="shift" class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                            <option value="">-- Select Shift --</option>
                            <option value="D6Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'D6Hours') ? 'selected' : ''; ?>>Day - 6 Hours</option>
                            <option value="D12Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'D12Hours') ? 'selected' : ''; ?>>Day - 12 Hours</option>
                            <option value="D24Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'D24Hours') ? 'selected' : ''; ?>>Day - 24 Hours</option>
                            <option value="N6Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'N6Hours') ? 'selected' : ''; ?>>Night - 6 Hours</option>
                            <option value="N12Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'N12Hours') ? 'selected' : ''; ?>>Night - 12 Hours</option>
                            <option value="N24Hours" <?php echo ($currentStatus && $currentStatus['duty_shift'] == 'N24Hours') ? 'selected' : ''; ?>>Night - 24 Hours</option>
                        </select>
                    </div>
                    
                    <div class="flex justify-end">
                        <button type="submit" name="update_status" id="update-status-btn" class="bg-red-600 hover:bg-red-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:ring-2 focus:ring-red-500">
                            Update Status
                        </button>
                    </div>
                </form>
            </div>
            
            <!-- Status History Section -->
            <div class="bg-white rounded-lg shadow p-6 mt-6">
                <h3 class="text-lg font-bold mb-4">Status Change History</h3>
                
                <?php
                // Fetch status log history
                try {
                    $logStmt = $pdo->prepare("
                        SELECT status_change, notes, change_timestamp 
                        FROM status_logs 
                        WHERE user_id = ? 
                        ORDER BY change_timestamp DESC
                        LIMIT 5
                    ");
                    $logStmt->execute([$targetUserId]);
                    $statusLogs = $logStmt->fetchAll(PDO::FETCH_ASSOC);
                } catch (PDOException $e) {
                    $statusLogs = [];
                }
                ?>
                
                <?php if (!empty($statusLogs)): ?>
                    <div class="overflow-x-auto">
                        <table class="min-w-full divide-y divide-gray-200 status-history-table">
                            <thead class="bg-gray-50">
                                <tr>
                                    <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Status</th>
                                    <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Notes</th>
                                    <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Timestamp</th>
                                </tr>
                            </thead>
                            <tbody class="bg-white divide-y divide-gray-200">
                                <?php foreach ($statusLogs as $log): ?>
                                    <tr>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm"><?php echo htmlspecialchars($log['status_change']); ?></td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm"><?php echo htmlspecialchars($log['notes']); ?></td>
                                        <td class="px-6 py-4 whitespace-nowrap text-sm"><?php echo htmlspecialchars($log['change_timestamp']); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php else: ?>
                    <p class="text-gray-500">No status change history found.</p>
                <?php endif; ?>
            </div>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
    
    <!-- Include JavaScript file -->
    <script src="js/duty-status.js"></script>
</body>
</html>