// form-loader.js - Improved version with better user info handling
(function() {
  // Function to extract user info from the page
  function extractUserInfo() {
    console.log('Extracting user info from the page');
    
    // First check if we already have valid user info
    if (window.userInfo && window.userInfo.fullname) {
      console.log('User info already available:', window.userInfo);
      return window.userInfo;
    }
    
    // Initialize user info object if it doesn't exist
    window.userInfo = window.userInfo || {};
    
    // Try to get user info from the hidden element
    var userDataElement = document.getElementById('user-data');
    if (userDataElement) {
      try {
        // Try to parse the data-user attribute
        var userData = JSON.parse(userDataElement.getAttribute('data-user'));
        if (userData) {
          console.log('Found user data in hidden element:', userData);
          // Update window.userInfo with the extracted data
          window.userInfo.fullname = userData.fullname || window.userInfo.fullname;
          window.userInfo.userId = userData.userId || window.userInfo.userId;
          window.userInfo.role = userData.role || window.userInfo.role;
          window.userInfo.username = userData.username || window.userInfo.username;
        }
      } catch (e) {
        console.warn('Error parsing user data from element:', e);
        // Try individual data attributes as fallback
        window.userInfo.fullname = userDataElement.getAttribute('data-fullname') || window.userInfo.fullname;
        window.userInfo.userId = userDataElement.getAttribute('data-user-id') || window.userInfo.userId;
        window.userInfo.role = userDataElement.getAttribute('data-user-role') || window.userInfo.role;
        window.userInfo.username = userDataElement.getAttribute('data-username') || window.userInfo.username;
      }
    }
    
    // Check for directly set PHP variables
    if (typeof PHP_USER_FULLNAME !== 'undefined') {
      window.userInfo.fullname = PHP_USER_FULLNAME || window.userInfo.fullname;
      window.userInfo.userId = PHP_USER_ID || window.userInfo.userId;
      window.userInfo.role = PHP_USER_ROLE || window.userInfo.role;
      window.userInfo.username = PHP_USERNAME || window.userInfo.username;
      console.log('Using PHP variables for user info:', window.userInfo);
    }
    
    // If still no fullname, try to find it in the DOM
    if (!window.userInfo.fullname) {
      // Look for common elements that might contain the username
      var userElements = document.querySelectorAll('.username, #username, .user-fullname, .user-welcome');
      for (var i = 0; i < userElements.length; i++) {
        var element = userElements[i];
        var text = element.textContent.trim();
        if (text && text.length > 0) {
          // Check if it contains "Welcome, " or similar text and extract the name
          if (text.indexOf('Welcome, ') === 0) {
            window.userInfo.fullname = text.replace('Welcome, ', '');
            console.log('Extracted fullname from welcome text:', window.userInfo.fullname);
            break;
          } else {
            // Just use the text as is
            window.userInfo.fullname = text;
            console.log('Extracted fullname from element:', window.userInfo.fullname);
            break;
          }
        }
      }
    }
    
    console.log('Final user info after extraction:', window.userInfo);
    return window.userInfo;
  }

  // Play silent sound to unlock audio on iOS
  function unlockAudioForIOS() {
    var silentSound = document.getElementById('silence-audio');
    if (silentSound) {
      try {
        silentSound.volume = 0.01;
        var playPromise = silentSound.play();
        
        if (playPromise !== undefined) {
          playPromise.catch(function(error) {
            console.log('Silent sound play prevented by browser:', error);
          });
        }
      } catch (e) {
        console.warn("Silent sound failed to play:", e);
      }
    }
  }

  // Setup touch events to unlock audio
  function setupAudioUnlock() {
    document.addEventListener('touchstart', function onFirstTouch() {
      unlockAudioForIOS();
      document.removeEventListener('touchstart', onFirstTouch, true);
    }, true);
    
    document.addEventListener('click', function onFirstClick() {
      unlockAudioForIOS();
      document.removeEventListener('click', onFirstClick, true);
    }, true);
  }

  // Initialize on page load
  document.addEventListener('DOMContentLoaded', function() {
    console.log('Form loader initialized');
    
    // Extract user info from the page
    var userInfo = extractUserInfo();
    
    // Setup audio unlock for mobile
    setupAudioUnlock();
    
    // Check if the current user info exists
    if (!userInfo.fullname) {
      console.warn('User information not available or incomplete.');
      // Don't redirect - just continue and let the component handle fallbacks
    }
  });
})();