async function handleSubmit(event) {
    event.preventDefault();
    
    if (isSubmitting) return;
    isSubmitting = true;
    
    const submitButton = document.getElementById('submit-button');
    submitButton.textContent = 'Submitting...';
    submitButton.disabled = true;
    
    document.getElementById('error-message').classList.add('hidden');
    
    try {
        // Get form data (updated to match new structure)
        const formData = {
            codeType: document.getElementById('code-type').value,
            location: document.getElementById('location').value,
            building: document.getElementById('building').value || null, // Explicit null
            reportedBy: document.getElementById('reported-by').value,
            details: document.getElementById('details').value,
            requestId: currentRequestId
        };

        // Submit to server
        const response = await fetch('save-report.php', {
            method: 'POST',
            headers: { 'Content-Type': 'application/json' },
            body: JSON.stringify(formData)
        });
        
        const result = await response.json();
        
        if (!response.ok) {
            throw new Error(result.error || result.message || 'Failed to submit report');
        }
        
        if (result.success) {
            document.getElementById('emergency-form').parentElement.classList.add('hidden');
            document.getElementById('success-message').classList.remove('hidden');
            
            // Play announcement only if not a duplicate
            if (!result.isDuplicate) {
                setTimeout(() => {
                    playAnnouncementAudio().catch(console.error);
                }, 100);
            }
            
            setTimeout(() => {
                resetForm();
                isSubmitting = false;
            }, 8000);
        } else {
            throw new Error(result.message || 'Submission failed');
        }
    } catch (err) {
        const errorElement = document.getElementById('error-message');
        const errorText = document.getElementById('error-text');
        errorText.textContent = err.message;
        errorElement.classList.remove('hidden');
        
        isSubmitting = false;
        submitButton.textContent = 'REPORT EMERGENCY CODE';
        updateSubmitButton();
        
        console.error('Submit error:', err);
    }
}

// Helper function to reset form
function resetForm() {
    document.getElementById('code-type').value = '';
    document.getElementById('location').value = '';
    document.getElementById('building').value = '';
    document.getElementById('details').value = '';
    document.querySelectorAll('.code-block').forEach(block => {
        block.classList.remove('ring-2', 'ring-blue-500');
    });
    document.getElementById('success-message').classList.add('hidden');
    document.getElementById('emergency-form').parentElement.classList.remove('hidden');
}