<script>
    // Cache DOM elements that are used frequently
    const messageContainer = document.getElementById('message-container');
    
    // Helper function to show messages
    function showMessage(type, message, autoHide = true) {
        const colors = {
            success: { bg: 'green', text: 'green' },
            error: { bg: 'red', text: 'red' }
        };
        
        messageContainer.innerHTML = `
            <div class="bg-${colors[type].bg}-100 border-l-4 border-${colors[type].bg}-500 text-${colors[type].text}-700 p-4 mb-4" role="alert">
                <p>${message}</p>
            </div>
        `;
        
        if (autoHide) {
            setTimeout(() => {
                messageContainer.innerHTML = '';
            }, 3000);
        }
    }

    // Modal functions
    function toggleModal(modalId, show) {
        document.getElementById(modalId).classList.toggle('hidden', !show);
    }

    // Show reset password modal
    function showResetPassword(userId, username) {
        document.getElementById('reset_user_id').value = userId;
        document.getElementById('reset_username').textContent = username;
        toggleModal('resetPasswordModal', true);
    }
    
    // Hide reset password modal
    function hideResetPassword() {
        toggleModal('resetPasswordModal', false);
    }
    
    // Show edit user modal
    function showEditUser(userId, username, fullname, email, role) {
        document.getElementById('edit_user_id').value = userId;
        document.getElementById('edit_username').value = username;
        document.getElementById('edit_fullname').value = fullname;
        document.getElementById('edit_email').value = email;
        document.getElementById('edit_role').value = role;
        toggleModal('editUserModal', true);
    }
    
    // Hide edit user modal
    function hideEditUser() {
        toggleModal('editUserModal', false);
    }
    
    // Handle form submissions with AJAX
    async function handleFormSubmit(form, options = {}) {
        try {
            const response = await fetch(form.action, {
                method: 'POST',
                body: new FormData(form)
            });
            
            if (!response.ok) throw new Error('Network response was not ok');
            
            return options.onSuccess ? options.onSuccess(response) : response.text();
        } catch (error) {
            console.error('Error:', error);
            showMessage('error', `Error: ${error.message}`);
            throw error;
        }
    }
    
    // Initialize when DOM is loaded
    document.addEventListener('DOMContentLoaded', function() {
        // Handle toggle status buttons
        document.querySelectorAll('.toggle-status-btn').forEach(button => {
            button.addEventListener('click', async function(e) {
                e.preventDefault();
                const userId = this.dataset.userId;
                const currentStatus = parseInt(this.dataset.currentStatus);
                const newStatus = currentStatus ? 0 : 1;
                const form = document.getElementById(`toggle-status-form-${userId}`);
                
                try {
                    await handleFormSubmit(form, {
                        onSuccess: () => {
                            // Update button
                            this.textContent = newStatus ? 'Deactivate' : 'Activate';
                            this.dataset.currentStatus = newStatus;
                            
                            // Toggle button classes
                            this.classList.toggle('text-green-600', !newStatus);
                            this.classList.toggle('hover:text-green-900', !newStatus);
                            this.classList.toggle('text-red-600', newStatus);
                            this.classList.toggle('hover:text-red-900', newStatus);
                            
                            // Update form for next toggle
                            form.querySelector('input[name="new_status"]').value = newStatus ? 0 : 1;
                            
                            showMessage('success', `User ${newStatus ? 'activated' : 'deactivated'} successfully.`);
                        }
                    });
                } catch (error) {
                    // Error already handled by handleFormSubmit
                }
            });
        });
        
        // Handle reset password form
        const resetPasswordForm = document.getElementById('reset-password-form');
        if (resetPasswordForm) {
            resetPasswordForm.addEventListener('submit', async function(e) {
                e.preventDefault();
                try {
                    await handleFormSubmit(this, {
                        onSuccess: () => {
                            hideResetPassword();
                            showMessage('success', 'Password reset successfully.');
                        }
                    });
                } catch (error) {
                    // Error already handled
                }
            });
        }
        
        // Handle edit user form
        const editUserForm = document.getElementById('edit-user-form');
        if (editUserForm) {
            editUserForm.addEventListener('submit', async function(e) {
                e.preventDefault();
                try {
                    await handleFormSubmit(this, {
                        onSuccess: () => {
                            const userId = document.getElementById('edit_user_id').value;
                            const username = document.getElementById('edit_username').value;
                            const fullname = document.getElementById('edit_fullname').value;
                            const email = document.getElementById('edit_email').value;
                            const role = document.getElementById('edit_role').value;
                            
                            // Update table row
                            const userRow = document.querySelector(`tr[data-user-id="${userId}"]`);
                            if (userRow) {
                                userRow.querySelector('td:nth-child(1)').textContent = username;
                                userRow.querySelector('td:nth-child(2)').textContent = fullname;
                                userRow.querySelector('td:nth-child(3)').textContent = email || 'N/A';
                                
                                const roleBadge = userRow.querySelector('td:nth-child(4) span');
                                if (roleBadge) {
                                    roleBadge.textContent = role.charAt(0).toUpperCase() + role.slice(1);
                                    roleBadge.classList.toggle('bg-purple-100', role === 'admin');
                                    roleBadge.classList.toggle('text-purple-800', role === 'admin');
                                    roleBadge.classList.toggle('bg-green-100', role !== 'admin');
                                    roleBadge.classList.toggle('text-green-800', role !== 'admin');
                                }
                            }
                            
                            hideEditUser();
                            showMessage('success', 'User updated successfully.');
                        }
                    });
                } catch (error) {
                    // Error already handled
                }
            });
        }
        
        // Handle create user form
        const createUserForm = document.getElementById('create-user-form');
        if (createUserForm) {
            createUserForm.addEventListener('submit', async function(e) {
                e.preventDefault();
                try {
                    await handleFormSubmit(this, {
                        onSuccess: async (response) => {
                            const html = await response.text();
                            const tempDiv = document.createElement('div');
                            tempDiv.innerHTML = html;
                            
                            if (tempDiv.querySelector('.bg-green-100')) {
                                createUserForm.reset();
                                window.location.reload();
                            } else {
                                const errorMessage = tempDiv.querySelector('.bg-red-100');
                                if (errorMessage) {
                                    messageContainer.innerHTML = errorMessage.outerHTML;
                                }
                            }
                        }
                    });
                } catch (error) {
                    // Error already handled
                }
            });
        }
    });
</script>