// This script handles the user data initialization
// It should be loaded before other application scripts

// Generate a unique request ID for this form session
const currentRequestId = (function() {
  return Date.now().toString(36) + Math.random().toString(36).substr(2, 5);
})();

// Initialize user info from data attributes if not already set by PHP
window.userInfo = window.userInfo || {};

// Try to get user info from the hidden user-data element if it exists
document.addEventListener('DOMContentLoaded', function() {
  const userDataElement = document.getElementById('user-data');
  
  if (userDataElement) {
    try {
      // Get from data-user attribute (JSON)
      const userData = JSON.parse(userDataElement.getAttribute('data-user') || '{}');
      
      // Use individual data attributes as fallback
      window.userInfo = {
        fullname: window.userInfo.fullname || userData.fullname || userDataElement.getAttribute('data-fullname'),
        userId: window.userInfo.userId || userData.userId || userDataElement.getAttribute('data-user-id'),
        role: window.userInfo.role || userData.role || userDataElement.getAttribute('data-user-role'),
        username: window.userInfo.username || userData.username || userDataElement.getAttribute('data-username')
      };
      
      console.log('User data initialized from DOM:', window.userInfo);
    } catch (error) {
      console.error('Error parsing user data:', error);
    }
  }
});