<?php
// my-reports.php
require_once 'db-connection.php';

session_start();

if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true) {
    header("Location: login.php");
    exit;
}

$userId = $_SESSION["user_id"] ?? 0;
$fullname = $_SESSION["fullname"] ?? "User";
$role = $_SESSION["role"] ?? "reporter";

// Get current user duty status
try {
    $stmt = $pdo->prepare("
        SELECT u.duty_status_id, u.duty_shift, d.status_name, d.description
        FROM users u
        LEFT JOIN duty_status d ON u.duty_status_id = d.id
        WHERE u.id = ?
    ");
    $stmt->execute([$userId]);
    $currentDutyStatus = $stmt->fetch(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $errorMessage = "Error fetching user duty status: " . $e->getMessage();
    $currentDutyStatus = null;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>My Reports - Emergency Code System</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link href="css/reports.css" rel="stylesheet">
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <img src="img/ksu-logo-64.png" alt="My Emergency Code Reports" class="w-32 h-32 object-contain" />
            <div class="flex items-center space-x-4">
                <a href="index.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">Report</a>
                <?php if ($_SESSION["role"] === "admin"): ?>
                    <a href="get-reports.php" class="bg-red-700 text-white py-1 px-3 rounded text-sm hover:bg-red-800">All Reports</a>
                <?php endif; ?>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto">
            <!-- Display current duty status -->
            <div class="bg-white rounded-lg shadow-md p-4 mb-6">
                <h2 class="text-lg font-bold mb-2">Current Duty Status</h2>
                <div class="flex justify-between items-center">
                    <div>
                        <?php if ($currentDutyStatus && $currentDutyStatus['duty_status_id']): ?>
                            <div class="flex items-center">
                                <span class="status-badge status-<?php echo strtolower(str_replace(' ', '-', $currentDutyStatus['status_name'] ?? 'unknown')); ?>">
                                    <?php echo htmlspecialchars($currentDutyStatus['status_name'] ?? 'Unknown'); ?>
                                </span>
                                <?php if ($currentDutyStatus['duty_shift']): ?>
                                    <span class="ml-3 text-sm text-gray-600">
                                        Shift: <?php echo htmlspecialchars($currentDutyStatus['duty_shift']); ?>
                                    </span>
                                <?php endif; ?>
                            </div>
                            <p class="text-sm text-gray-600 mt-1">
                                <?php echo htmlspecialchars($currentDutyStatus['description'] ?? ''); ?>
                            </p>
                        <?php else: ?>
                            <p class="text-gray-500">No duty status set. Please update your duty status.</p>
                        <?php endif; ?>
                    </div>
                    <a href="update-duty-status.php?user_id=<?php echo $_SESSION['user_id']; ?>" class="bg-blue-600 hover:bg-blue-700 text-white p-2 rounded inline-flex items-center justify-center transition-all duration-300">
                        <svg xmlns="http://www.w3.org/2000/svg" class="h-5 w-5" viewBox="0 0 20 20" fill="currentColor">
                            <path d="M13.586 3.586a2 2 0 112.828 2.828l-.793.793-2.828-2.828.793-.793zM11.379 5.793L3 14.172V17h2.828l8.38-8.379-2.83-2.828z" />
                        </svg>
                        <span class="sr-only">Update Status</span>
                    </a>
                </div>
            </div>
            
            <div class="bg-white rounded-lg shadow p-6">
                <div class="flex justify-between items-center mb-6">
                    <div class="flex items-center space-x-2">
                        <svg xmlns="http://www.w3.org/2000/svg" class="h-6 w-6 text-gray-800" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M3 10h11M9 21V3m0 0L3 10m6-7l6 7" />
                        </svg>
                        <h2 class="text-xl font-bold text-gray-800">My Reported Emergencies</h2>
                    </div>
                    <div class="flex space-x-2">
                        <select id="status-filter" class="border border-gray-300 rounded px-3 py-1 focus:outline-none focus:ring-2 focus:ring-red-500">
                            <option value="">All Statuses</option>
                            <option value="active">Active</option>
                            <option value="resolved">Resolved</option>
                            <option value="false_alarm">False Alarm</option>
                        </select>
                        <button id="refresh-btn" class="bg-blue-500 hover:bg-blue-600 text-white px-3 py-1 rounded">
                            Refresh
                        </button>
                    </div>
                </div>
                
                <div class="overflow-x-auto">
                    <table class="min-w-full divide-y divide-gray-200">
                        <thead class="bg-gray-50">
                            <tr>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Report ID</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Code</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Location</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Time</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Status</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
                            </tr>
                        </thead>
                        <tbody id="reports-table-body" class="bg-white divide-y divide-gray-200">
                            <tr>
                                <td colspan="6" class="px-6 py-4 text-center text-gray-500">Loading your reports...</td>
                            </tr>
                        </tbody>
                    </table>
                </div>
                
                <div class="mt-4 flex justify-between items-center">
                    <div class="text-sm text-gray-500" id="reports-count">
                        Loading...
                    </div>
                    <div class="flex space-x-2">
                        <button id="prev-page" class="px-3 py-1 border border-gray-300 rounded disabled:opacity-50">
                            Previous
                        </button>
                        <button id="next-page" class="px-3 py-1 border border-gray-300 rounded disabled:opacity-50">
                            Next
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </main>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
        <p class="mt-1">For actual emergencies, follow hospital protocols and use designated emergency systems.</p>
    </footer>
    
    <!-- Report details modal -->
    <div id="report-modal" class="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center hidden">
        <div class="bg-white rounded-lg max-w-2xl w-full p-6 max-h-screen overflow-auto">
            <div class="flex justify-between items-center mb-4">
                <h3 class="text-xl font-bold" id="modal-title">Report Details</h3>
                <button id="close-modal" class="text-gray-500 hover:text-gray-700">
                    <svg class="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 18L18 6M6 6l12 12"></path>
                    </svg>
                </button>
            </div>
            <div id="modal-content">
                <!-- Report details will be loaded here -->
            </div>
        </div>
    </div>
    
    <script src="js/reports.js"></script>
    <script src="js/announcement-player.js"></script>
</body>
</html>