-- Create the database for the emergency code system
CREATE DATABASE IF NOT EXISTS bangsaho_emergency_code_system;

-- Use the database
USE bangsaho_emergency_code_system;

-- Create a table for emergency codes
CREATE TABLE IF NOT EXISTS emergency_codes (
  id INT AUTO_INCREMENT PRIMARY KEY,
  code_value VARCHAR(50) NOT NULL,
  label VARCHAR(100) NOT NULL,
  description VARCHAR(255) NOT NULL,
  arabic_text VARCHAR(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  bg_color VARCHAR(20) NOT NULL,
  text_color VARCHAR(20) NOT NULL
);

-- Insert the emergency codes that match our application
INSERT INTO emergency_codes (code_value, label, description, arabic_text, bg_color, text_color) VALUES
('code-red', 'CODE RED', 'Fire', 'حريق', '#FF3333', 'white'),
('code-yellow', 'CODE YELLOW', 'External Disaster', 'الكوارث الخارجية', '#FFDC46', 'black'),
('code-black', 'CODE BLACK', 'BOMB THREAT', 'التهديد بزرع قنبلة', '#000000', 'white'),
('code-orange', 'CODE ORANGE', 'Chemical, Radioactive, Biological Spill', 'تسرب بيولوجي،كيميائي،إشعاعي', '#FF9966', 'white');

-- Create a table for hospital locations
CREATE TABLE IF NOT EXISTS locations (
  id INT AUTO_INCREMENT PRIMARY KEY,
  name VARCHAR(100) NOT NULL
);

-- Insert the locations
INSERT INTO locations (name) VALUES
('Emergency Room'),
('ICU'),
('Surgery Center'),
('Pediatrics'),
('Radiology'),
('Laboratory'),
('Cafeteria'),
('Administration'),
('Main Entrance'),
('Parking Garage');

-- Create the main table for code reports
CREATE TABLE IF NOT EXISTS code_reports (
  id INT AUTO_INCREMENT PRIMARY KEY,
  code_id VARCHAR(50) NOT NULL,
  location_id VARCHAR(100) NOT NULL,
  reported_by VARCHAR(100) NOT NULL,
  details TEXT,
  report_timestamp DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
  ip_address VARCHAR(45),
  user_agent TEXT,
  status ENUM('active', 'resolved', 'false_alarm') NOT NULL DEFAULT 'active',
  response_time INT,
  FOREIGN KEY (code_id) REFERENCES emergency_codes(code_value) ON DELETE RESTRICT,
  INDEX (report_timestamp),
  INDEX (status)
);

-- Create a table for report updates/comments
CREATE TABLE IF NOT EXISTS report_updates (
  id INT AUTO_INCREMENT PRIMARY KEY,
  report_id INT NOT NULL,
  update_text TEXT NOT NULL,
  updated_by VARCHAR(100) NOT NULL,
  update_timestamp DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
  FOREIGN KEY (report_id) REFERENCES code_reports(id) ON DELETE CASCADE
);

-- Create a trigger to add a default initial update when a report is created
DELIMITER //
CREATE TRIGGER after_report_insert
AFTER INSERT ON code_reports
FOR EACH ROW
BEGIN
  INSERT INTO report_updates (report_id, update_text, updated_by)
  VALUES (NEW.id, 'Emergency code reported.', NEW.reported_by);
END //
DELIMITER ;
