# Emergency Code Reporter - Database Integration

This document explains how to set up the MySQL database for the Emergency Code Reporter application and deploy the backend files.

## Database Setup

1. **Create the MySQL Database**

   Execute the SQL script in `mysql-schema.sql` to create the database structure:

   ```bash
   mysql -u your_username -p < mysql-schema.sql
   ```

   Or you can copy and paste the contents of the script into your MySQL client.

2. **Configure Database Connection**

   Edit the `db-connection.php` file and update the following variables with your actual MySQL credentials:

   ```php
   $host = 'localhost';      // Your MySQL host
   $dbname = 'bangsaho_emergency_code_system';
   $username = 'bangsaho_emergency_code_system_u';  // Database username
   $password = '@Allahx452030';  // Database password
   ```

## File Deployment

1. **Frontend Files**
   - index.html
   - app.js

2. **Backend Files**
   - db-connection.php
   - save-report.php
   - get-reports.php

All files should be uploaded to your web server in the same directory.

## Security Considerations

For a production environment, consider implementing these additional security measures:

1. **Add Authentication**
   - Implement a login system to restrict access to authorized personnel
   - Use JWT or session-based authentication for API endpoints

2. **Implement HTTPS**
   - Ensure all traffic is encrypted with SSL/TLS
   - Obtain and install an SSL certificate for your domain

3. **Additional Database Security**
   - Create a dedicated database user with limited permissions
   - Implement IP restrictions for database access

4. **Input Validation**
   - Add more comprehensive validation for all user inputs
   - Consider using a validation library

## API Endpoints

### 1. Save Emergency Report

**Endpoint:** `save-report.php`
**Method:** POST
**Content-Type:** application/json

**Request Body:**
```json
{
  "codeType": "code-red",
  "location": "Emergency Room",
  "reportedBy": "John Doe",
  "details": "Small fire in trash bin"
}
```

**Response:**
```json
{
  "success": true,
  "message": "Emergency code reported successfully",
  "reportId": 123,
  "timestamp": "2025-03-22 14:30:45"
}
```

### 2. Get Emergency Reports

**Endpoint:** `get-reports.php`
**Method:** GET

**Query Parameters:**
- `limit` (optional): Number of records to return (default: 20, max: 100)
- `offset` (optional): Number of records to skip (default: 0)
- `status` (optional): Filter by status (active, resolved, false_alarm)

**Response:**
```json
{
  "success": true,
  "reports": [
    {
      "id": 123,
      "code_label": "CODE RED",
      "code_description": "Fire",
      "location": "Emergency Room",
      "reported_by": "John Doe",
      "details": "Small fire in trash bin",
      "report_time": "2025-03-22 14:30:45",
      "status": "active"
    },
    // More records...
  ],
  "pagination": {
    "total": 45,
    "limit": 20,
    "offset": 0,
    "hasMore": true
  }
}
```

## Troubleshooting

1. **Database Connection Issues**
   - Verify your database credentials and connection settings
   - Ensure the MySQL server is running and accessible
   - Check for any firewall restrictions

2. **File Permission Issues**
   - Ensure PHP has write permissions if needed
   - Set appropriate permissions on configuration files

3. **PHP Errors**
   - Check your web server's error log
   - Enable error reporting temporarily for debugging
