<?php
// This is a test script to help diagnose issues with save-report.php
// Use this for debugging only, then remove from your server

// Enable full error reporting
ini_set('display_errors', 1);
error_reporting(E_ALL);

// Start session
session_start();

// Debug information
echo "<h1>Session Status</h1>";
echo "<pre>";
print_r($_SESSION);
echo "</pre>";

// Test database connection
echo "<h1>Database Connection Test</h1>";
try {
    require_once 'db-connection.php';
    echo "<p style='color:green'>Database connection successful</p>";
    
    // Test emergency_codes table
    $query = "SELECT * FROM emergency_codes LIMIT 5";
    $stmt = $pdo->query($query);
    $codes = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<h2>Sample Emergency Codes</h2>";
    echo "<pre>";
    print_r($codes);
    echo "</pre>";
    
    // Test locations table
    $query = "SELECT * FROM locations LIMIT 5";
    $stmt = $pdo->query($query);
    $locations = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<h2>Sample Locations</h2>";
    echo "<pre>";
    print_r($locations);
    echo "</pre>";
    
    // Test buildings table
    $query = "SELECT * FROM buildings";
    $stmt = $pdo->query($query);
    $buildings = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<h2>Buildings</h2>";
    echo "<pre>";
    print_r($buildings);
    echo "</pre>";
    
} catch (Exception $e) {
    echo "<p style='color:red'>Database error: " . $e->getMessage() . "</p>";
}

// Test POST to save-report.php
echo "<h1>Test POST Request to save-report.php</h1>";
?>

<form method="post" action="save-report-test.php">
    <button type="submit">Test POST Request</button>
</form>

<script>
// Function to test API directly
async function testSaveReport() {
    try {
        const testData = {
            codeType: 'code-red',
            location: 'Emergency Room',
            selectedBuilding: 'Main Hospital Building',
            reportedBy: 'Test User',
            details: 'This is a test submission',
            textToAudio: 'CODE RED Main Hospital Building Emergency Room This is a test submission'
        };
        
        console.log('Sending test data:', testData);
        
        const response = await fetch('save-report.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify(testData)
        });
        
        const responseText = await response.text();
        console.log('Raw response:', responseText);
        
        try {
            const result = JSON.parse(responseText);
            console.log('Parsed result:', result);
            document.getElementById('api-result').innerHTML = `
                <pre style="background-color: #f4f4f4; padding: 10px; overflow: auto;">
Status: ${response.status}
Success: ${result.success ? 'Yes' : 'No'}
Message: ${result.message || result.error || 'No message'}
Report ID: ${result.reportId || 'N/A'}
                </pre>
            `;
        } catch (e) {
            document.getElementById('api-result').innerHTML = `
                <p style="color: red">Error parsing JSON response:</p>
                <pre style="background-color: #f4f4f4; padding: 10px; overflow: auto;">
Status: ${response.status}
Raw response: ${responseText}
                </pre>
            `;
        }
    } catch (error) {
        console.error('Error:', error);
        document.getElementById('api-result').innerHTML = `
            <p style="color: red">Error: ${error.message}</p>
        `;
    }
}
</script>

<div style="margin-top: 20px; margin-bottom: 20px;">
    <button onclick="testSaveReport()">Test API Request</button>
    <div id="api-result" style="margin-top: 10px;"></div>
</div>

<h1>Manual POST Data Test</h1>
<form method="post" action="save-report.php">
    <fieldset>
        <legend>Test Form Submission</legend>
        <p>This won't work directly because save-report.php expects JSON, but the results can help debug.</p>
        <div>
            <label>Code Type:</label>
            <input type="text" name="codeType" value="code-red">
        </div>
        <div>
            <label>Location:</label>
            <input type="text" name="location" value="Emergency Room">
        </div>
        <div>
            <label>Building:</label>
            <input type="text" name="selectedBuilding" value="Main Hospital Building">
        </div>
        <div>
            <label>Reported By:</label>
            <input type="text" name="reportedBy" value="Test User">
        </div>
        <div>
            <label>Details:</label>
            <textarea name="details">This is a test submission</textarea>
        </div>
        <div>
            <button type="submit">Test Direct Form POST</button>
        </div>
    </fieldset>
</form>