<?php
// Start session - for access control (only admins should access this)
session_start();

// Check if user is logged in and is admin
if (!isset($_SESSION["loggedin"]) || $_SESSION["loggedin"] !== true || $_SESSION["role"] !== "admin") {
    echo "<script>window.location.href = 'login.php';</script>";
    exit;
}

// Include database connection
require_once 'db-connection.php';

// Define variables
$error_message = "";
$success_message = "";

// Get all users
try {
    $sql = "SELECT u.id, u.username, u.fullname, u.email, u.role, ds.status_name as duty_status, 
            u.duty_shift as shift, u.last_login, u.created_at, u.active, u.team_id
            FROM users u 
            LEFT JOIN duty_status ds ON u.duty_status_id = ds.id 
            ORDER BY u.created_at DESC";
    $users = $pdo->query($sql)->fetchAll();
} catch (PDOException $e) {
    $error_message = "Could not fetch users: " . $e->getMessage();
    $users = [];
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>User Management - Emergency Code System</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <link rel="stylesheet" href="css/style.css">
</head>
<body class="bg-gray-100 min-h-screen flex flex-col">
    <header class="bg-red-600 text-white p-4 shadow-md">
        <div class="container mx-auto flex justify-between items-center">
            <h1 class="text-2xl font-bold">User Management</h1>
            <div class="flex items-center space-x-4">
                <a href="get-reports.php" class="text-white hover:underline">Back to Reports</a>
                <span class="text-sm">Welcome, <?php echo htmlspecialchars($_SESSION["fullname"]); ?></span>
                <a href="logout-script.php" class="bg-white text-red-600 py-1 px-3 rounded text-sm hover:bg-gray-100">Logout</a>
            </div>
        </div>
    </header>
    
    <main class="flex-grow p-4">
        <div class="container mx-auto">
            <?php if(!empty($error_message)): ?>
                <div class="bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4" role="alert">
                    <p><?php echo $error_message; ?></p>
                </div>
            <?php endif; ?>
            
            <?php if(!empty($success_message)): ?>
                <div class="bg-green-100 border-l-4 border-green-500 text-green-700 p-4 mb-4" role="alert">
                    <p><?php echo $success_message; ?></p>
                </div>
            <?php endif; ?>
            
            <div class="bg-white rounded-lg shadow-md p-6 mb-6">
                <h2 class="text-xl font-bold mb-4">Create New User</h2>
                <form method="post" action="api/create-user.php">
                    <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                        <div>
                            <label for="username" class="block text-sm font-medium text-gray-700 mb-1">Username *</label>
                            <input type="text" name="username" id="username" required 
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                        </div>
                        <div>
                            <label for="password" class="block text-sm font-medium text-gray-700 mb-1">Password *</label>
                            <input type="password" name="password" id="password" required 
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                        </div>
                        <div>
                            <label for="fullname" class="block text-sm font-medium text-gray-700 mb-1">Full Name *</label>
                            <input type="text" name="fullname" id="fullname" required 
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                        </div>
                        <div>
                            <label for="emp_id" class="block text-sm font-medium text-gray-700 mb-1">Employee ID</label>
                            <input type="text" name="emp_id" id="emp_id"
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                        </div>
                        <div>
                            <label for="email" class="block text-sm font-medium text-gray-700 mb-1">Email</label>
                            <input type="email" name="email" id="email" 
                                   class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                        </div>
                        <div>
                            <label for="role" class="block text-sm font-medium text-gray-700 mb-1">Role *</label>
                            <select name="role" id="role" required 
                                    class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                                <option value="reporter">Reporter</option>
                                <option value="admin">Admin</option>
                            </select>
                        </div>
                    </div>
                    <div class="mt-4">
                        <button type="submit" class="bg-green-500 hover:bg-green-600 text-white font-bold py-2 px-4 rounded">
                            Create User
                        </button>
                    </div>
                </form>
            </div>     
            
            <div class="bg-white rounded-lg shadow-md overflow-hidden">
                <h2 class="text-xl font-bold p-6 bg-gray-50 border-b">User List</h2>
                
                <div class="overflow-x-auto">
                    <table class="min-w-full divide-y divide-gray-200">
                        <thead class="bg-gray-50">
                            <tr>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Name</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Role</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Team</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Duty Status</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Shift</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Last Login</th>
                                <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Actions</th>
                            </tr>
                        </thead>
                        <tbody class="bg-white divide-y divide-gray-200">
                            <?php foreach ($users as $user): ?>
                            <tr>
                                <td class="px-6 py-4 whitespace-nowrap">
                                    <?php echo htmlspecialchars($user['fullname']); ?>
                                </td>
                                <td class="px-6 py-4 whitespace-nowrap">
                                    <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full 
                                        <?php echo $user['role'] === 'admin' ? 'bg-purple-100 text-purple-800' : 'bg-green-100 text-green-800'; ?>">
                                        <?php echo ucfirst(htmlspecialchars($user['role'])); ?>
                                    </span>
                                </td>
                                <td class="px-6 py-4 whitespace-nowrap">
                                    <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-yellow-100 text-yellow-800">
                                        <?php echo $user['team_id'] ? htmlspecialchars($user['team_id']) : 'Not assigned'; ?>
                                    </span>
                                </td>
                                <td class="px-6 py-4 whitespace-nowrap">
                                    <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full 
                                        <?php echo ($user['duty_status'] && strpos(strtolower($user['duty_status']), 'on') !== false) ? 'bg-green-100 text-green-800' : 'bg-red-100 text-red-800'; ?>">
                                        <?php echo $user['duty_status'] ? htmlspecialchars($user['duty_status']) : 'Not assigned'; ?>
                                    </span>
                                </td>
                                <td class="px-6 py-4 whitespace-nowrap">
                                    <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full bg-blue-100 text-blue-800">
                                        <?php 
                                        if ($user['shift']) {
                                            $shift_display = $user['shift'];
                                            $shift_display = str_replace('Hours', ' Hours', $shift_display);
                                            $shift_display = str_replace('D', 'Day ', $shift_display);
                                            $shift_display = str_replace('N', 'Night ', $shift_display);
                                            echo htmlspecialchars($shift_display);
                                        } else {
                                            echo 'Not assigned';
                                        }
                                        ?>
                                    </span>
                                </td>
                                <td class="px-6 py-4 whitespace-nowrap text-sm text-gray-500">
                                    <?php echo $user['last_login'] ? htmlspecialchars($user['last_login']) : 'Never'; ?>
                                </td>
                                <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                                    <a href="edit-user-page.php?id=<?php echo $user['id']; ?>" class="text-blue-600 hover:text-blue-900 mr-3" title="Edit User">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    
                                    <button onclick="showResetPassword(<?php echo $user['id']; ?>, '<?php echo htmlspecialchars($user['username']); ?>')" 
                                            class="text-indigo-600 hover:text-indigo-900 mr-3" title="Reset Password">
                                        <i class="fas fa-key"></i>
                                    </button>
                                    
                                    <a href="update-duty-status.php?user_id=<?php echo $user['id']; ?>" class="text-green-600 hover:text-green-900 mr-3" title="Update Duty Status & Shift">
                                        <i class="fas fa-calendar-alt"></i>
                                    </a>
                                    
                                    <?php if ($user['id'] != $_SESSION['user_id']): ?>
                                    <button onclick="toggleUserStatus(<?php echo $user['id']; ?>, <?php echo $user['active'] ? 'false' : 'true'; ?>)" 
                                            class="<?php echo $user['active'] ? 'text-red-600 hover:text-red-900' : 'text-green-600 hover:text-green-900'; ?>"
                                            title="<?php echo $user['active'] ? 'Deactivate User' : 'Activate User'; ?>">
                                        <?php if ($user['active']): ?>
                                        <i class="fas fa-user-times"></i>
                                        <?php else: ?>
                                        <i class="fas fa-user-check"></i>
                                        <?php endif; ?>
                                    </button>
                                    <?php endif; ?>
                                </td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </main>
    
    <!-- Password Reset Modal -->
    <div id="resetPasswordModal" class="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center hidden">
        <div class="bg-white rounded-lg max-w-md w-full p-6">
            <h3 class="text-lg font-bold mb-4">Reset Password</h3>
            <form method="post" action="api/reset-password.php">
                <input type="hidden" name="user_id" id="reset_user_id">
                
                <p class="mb-4">Reset password for user: <span id="reset_username" class="font-bold"></span></p>
                
                <div class="mb-4">
                    <label for="new_password" class="block text-sm font-medium text-gray-700 mb-1">New Password</label>
                    <input type="password" name="new_password" id="new_password" required 
                           class="w-full px-3 py-2 border border-gray-300 rounded-md focus:outline-none focus:ring-2 focus:ring-red-500">
                </div>
                
                <div class="flex justify-end space-x-3">
                    <button type="button" onclick="hideResetPassword()" 
                            class="bg-gray-300 hover:bg-gray-400 text-gray-800 font-bold py-2 px-4 rounded">
                        Cancel
                    </button>
                    <button type="submit" 
                            class="bg-blue-500 hover:bg-blue-600 text-white font-bold py-2 px-4 rounded">
                        Reset Password
                    </button>
                </div>
            </form>
        </div>
    </div>
    
    <footer class="bg-gray-800 text-white p-4 text-center text-sm">
        <p>Hospital Emergency Response System &copy; <?php echo date("Y"); ?></p>
    </footer>
    
    <script src="js/script1.js"></script>
</body>
</html>